% Intrinsic and Extrinsic Camera Parameters
%
% This script file can be directly excecuted under Matlab to recover the camera intrinsic and extrinsic parameters.
% IMPORTANT: This file contains neither the structure of the calibration objects nor the image coordinates of the calibration points.
%            All those complementary variables are saved in the complete matlab data file Calib_Results.mat.
% For more information regarding the calibration model visit http://www.vision.caltech.edu/bouguetj/calib_doc/


%-- Focal length:
fc = [ 209.342203506000743 ; 209.816265217030917 ];

%-- Principal point:
cc = [ 362.924485552740293 ; 249.842158495865050 ];

%-- Skew coefficient:
alpha_c = -0.000533727297774;

%-- Distortion coefficients:
kc = [ 0.013295073294967 ; -0.010559276675242 ; 0.001578405929311 ; 0.000570327666002 ; 0.001528004325489 ];

%-- Focal length uncertainty:
fc_error = [ 0.908864675049342 ; 0.809103780277802 ];

%-- Principal point uncertainty:
cc_error = [ 0.516942173522465 ; 0.924813949541832 ];

%-- Skew coefficient uncertainty:
alpha_c_error = 0.001083138796992;

%-- Distortion coefficients uncertainty:
kc_error = [ 0.001675398926791 ; 0.001082903389610 ; 0.000426661175332 ; 0.000491710666444 ; 0.000213028346732 ];

%-- Image size:
nx = 752;
ny = 480;


%-- Various other variables (may be ignored if you do not use the Matlab Calibration Toolbox):
%-- Those variables are used to control which intrinsic parameters should be optimized

n_ima = 539;						% Number of calibration images
est_fc = [ 1 ; 1 ];					% Estimation indicator of the two focal variables
est_aspect_ratio = 1;				% Estimation indicator of the aspect ratio fc(2)/fc(1)
center_optim = 1;					% Estimation indicator of the principal point
est_alpha = 1;						% Estimation indicator of the skew coefficient
est_dist = [ 1 ; 1 ; 1 ; 1 ; 1 ];	% Estimation indicator of the distortion coefficients


%-- Extrinsic parameters:
%-- The rotation (omc_kk) and the translation (Tc_kk) vectors for every calibration image and their uncertainties

%-- Image #1:
omc_1 = [ 2.406779e+00 ; 5.914853e-01 ; -2.854035e-01 ];
Tc_1  = [ -6.683583e+02 ; 5.356704e+01 ; 9.902229e+02 ];
omc_error_1 = [ 3.672612e-03 ; 1.514718e-03 ; 2.836832e-03 ];
Tc_error_1  = [ 2.476902e+00 ; 4.514710e+00 ; 4.418716e+00 ];

%-- Image #2:
omc_2 = [ NaN ; NaN ; NaN ];
Tc_2  = [ NaN ; NaN ; NaN ];
omc_error_2 = [ NaN ; NaN ; NaN ];
Tc_error_2  = [ NaN ; NaN ; NaN ];

%-- Image #3:
omc_3 = [ NaN ; NaN ; NaN ];
Tc_3  = [ NaN ; NaN ; NaN ];
omc_error_3 = [ NaN ; NaN ; NaN ];
Tc_error_3  = [ NaN ; NaN ; NaN ];

%-- Image #4:
omc_4 = [ NaN ; NaN ; NaN ];
Tc_4  = [ NaN ; NaN ; NaN ];
omc_error_4 = [ NaN ; NaN ; NaN ];
Tc_error_4  = [ NaN ; NaN ; NaN ];

%-- Image #5:
omc_5 = [ NaN ; NaN ; NaN ];
Tc_5  = [ NaN ; NaN ; NaN ];
omc_error_5 = [ NaN ; NaN ; NaN ];
Tc_error_5  = [ NaN ; NaN ; NaN ];

%-- Image #6:
omc_6 = [ NaN ; NaN ; NaN ];
Tc_6  = [ NaN ; NaN ; NaN ];
omc_error_6 = [ NaN ; NaN ; NaN ];
Tc_error_6  = [ NaN ; NaN ; NaN ];

%-- Image #7:
omc_7 = [ NaN ; NaN ; NaN ];
Tc_7  = [ NaN ; NaN ; NaN ];
omc_error_7 = [ NaN ; NaN ; NaN ];
Tc_error_7  = [ NaN ; NaN ; NaN ];

%-- Image #8:
omc_8 = [ NaN ; NaN ; NaN ];
Tc_8  = [ NaN ; NaN ; NaN ];
omc_error_8 = [ NaN ; NaN ; NaN ];
Tc_error_8  = [ NaN ; NaN ; NaN ];

%-- Image #9:
omc_9 = [ NaN ; NaN ; NaN ];
Tc_9  = [ NaN ; NaN ; NaN ];
omc_error_9 = [ NaN ; NaN ; NaN ];
Tc_error_9  = [ NaN ; NaN ; NaN ];

%-- Image #10:
omc_10 = [ NaN ; NaN ; NaN ];
Tc_10  = [ NaN ; NaN ; NaN ];
omc_error_10 = [ NaN ; NaN ; NaN ];
Tc_error_10  = [ NaN ; NaN ; NaN ];

%-- Image #11:
omc_11 = [ NaN ; NaN ; NaN ];
Tc_11  = [ NaN ; NaN ; NaN ];
omc_error_11 = [ NaN ; NaN ; NaN ];
Tc_error_11  = [ NaN ; NaN ; NaN ];

%-- Image #12:
omc_12 = [ NaN ; NaN ; NaN ];
Tc_12  = [ NaN ; NaN ; NaN ];
omc_error_12 = [ NaN ; NaN ; NaN ];
Tc_error_12  = [ NaN ; NaN ; NaN ];

%-- Image #13:
omc_13 = [ 2.637296e+00 ; 9.925079e-01 ; -2.268559e-01 ];
Tc_13  = [ -6.886828e+02 ; -4.537402e+02 ; 9.375151e+02 ];
omc_error_13 = [ 2.484416e-03 ; 1.342288e-03 ; 2.819971e-03 ];
Tc_error_13  = [ 2.102724e+00 ; 3.620476e+00 ; 4.823355e+00 ];

%-- Image #14:
omc_14 = [ NaN ; NaN ; NaN ];
Tc_14  = [ NaN ; NaN ; NaN ];
omc_error_14 = [ NaN ; NaN ; NaN ];
Tc_error_14  = [ NaN ; NaN ; NaN ];

%-- Image #15:
omc_15 = [ NaN ; NaN ; NaN ];
Tc_15  = [ NaN ; NaN ; NaN ];
omc_error_15 = [ NaN ; NaN ; NaN ];
Tc_error_15  = [ NaN ; NaN ; NaN ];

%-- Image #16:
omc_16 = [ NaN ; NaN ; NaN ];
Tc_16  = [ NaN ; NaN ; NaN ];
omc_error_16 = [ NaN ; NaN ; NaN ];
Tc_error_16  = [ NaN ; NaN ; NaN ];

%-- Image #17:
omc_17 = [ NaN ; NaN ; NaN ];
Tc_17  = [ NaN ; NaN ; NaN ];
omc_error_17 = [ NaN ; NaN ; NaN ];
Tc_error_17  = [ NaN ; NaN ; NaN ];

%-- Image #18:
omc_18 = [ NaN ; NaN ; NaN ];
Tc_18  = [ NaN ; NaN ; NaN ];
omc_error_18 = [ NaN ; NaN ; NaN ];
Tc_error_18  = [ NaN ; NaN ; NaN ];

%-- Image #19:
omc_19 = [ NaN ; NaN ; NaN ];
Tc_19  = [ NaN ; NaN ; NaN ];
omc_error_19 = [ NaN ; NaN ; NaN ];
Tc_error_19  = [ NaN ; NaN ; NaN ];

%-- Image #20:
omc_20 = [ NaN ; NaN ; NaN ];
Tc_20  = [ NaN ; NaN ; NaN ];
omc_error_20 = [ NaN ; NaN ; NaN ];
Tc_error_20  = [ NaN ; NaN ; NaN ];

%-- Image #21:
omc_21 = [ NaN ; NaN ; NaN ];
Tc_21  = [ NaN ; NaN ; NaN ];
omc_error_21 = [ NaN ; NaN ; NaN ];
Tc_error_21  = [ NaN ; NaN ; NaN ];

%-- Image #22:
omc_22 = [ NaN ; NaN ; NaN ];
Tc_22  = [ NaN ; NaN ; NaN ];
omc_error_22 = [ NaN ; NaN ; NaN ];
Tc_error_22  = [ NaN ; NaN ; NaN ];

%-- Image #23:
omc_23 = [ NaN ; NaN ; NaN ];
Tc_23  = [ NaN ; NaN ; NaN ];
omc_error_23 = [ NaN ; NaN ; NaN ];
Tc_error_23  = [ NaN ; NaN ; NaN ];

%-- Image #24:
omc_24 = [ NaN ; NaN ; NaN ];
Tc_24  = [ NaN ; NaN ; NaN ];
omc_error_24 = [ NaN ; NaN ; NaN ];
Tc_error_24  = [ NaN ; NaN ; NaN ];

%-- Image #25:
omc_25 = [ NaN ; NaN ; NaN ];
Tc_25  = [ NaN ; NaN ; NaN ];
omc_error_25 = [ NaN ; NaN ; NaN ];
Tc_error_25  = [ NaN ; NaN ; NaN ];

%-- Image #26:
omc_26 = [ NaN ; NaN ; NaN ];
Tc_26  = [ NaN ; NaN ; NaN ];
omc_error_26 = [ NaN ; NaN ; NaN ];
Tc_error_26  = [ NaN ; NaN ; NaN ];

%-- Image #27:
omc_27 = [ NaN ; NaN ; NaN ];
Tc_27  = [ NaN ; NaN ; NaN ];
omc_error_27 = [ NaN ; NaN ; NaN ];
Tc_error_27  = [ NaN ; NaN ; NaN ];

%-- Image #28:
omc_28 = [ NaN ; NaN ; NaN ];
Tc_28  = [ NaN ; NaN ; NaN ];
omc_error_28 = [ NaN ; NaN ; NaN ];
Tc_error_28  = [ NaN ; NaN ; NaN ];

%-- Image #29:
omc_29 = [ NaN ; NaN ; NaN ];
Tc_29  = [ NaN ; NaN ; NaN ];
omc_error_29 = [ NaN ; NaN ; NaN ];
Tc_error_29  = [ NaN ; NaN ; NaN ];

%-- Image #30:
omc_30 = [ NaN ; NaN ; NaN ];
Tc_30  = [ NaN ; NaN ; NaN ];
omc_error_30 = [ NaN ; NaN ; NaN ];
Tc_error_30  = [ NaN ; NaN ; NaN ];

%-- Image #31:
omc_31 = [ NaN ; NaN ; NaN ];
Tc_31  = [ NaN ; NaN ; NaN ];
omc_error_31 = [ NaN ; NaN ; NaN ];
Tc_error_31  = [ NaN ; NaN ; NaN ];

%-- Image #32:
omc_32 = [ NaN ; NaN ; NaN ];
Tc_32  = [ NaN ; NaN ; NaN ];
omc_error_32 = [ NaN ; NaN ; NaN ];
Tc_error_32  = [ NaN ; NaN ; NaN ];

%-- Image #33:
omc_33 = [ NaN ; NaN ; NaN ];
Tc_33  = [ NaN ; NaN ; NaN ];
omc_error_33 = [ NaN ; NaN ; NaN ];
Tc_error_33  = [ NaN ; NaN ; NaN ];

%-- Image #34:
omc_34 = [ NaN ; NaN ; NaN ];
Tc_34  = [ NaN ; NaN ; NaN ];
omc_error_34 = [ NaN ; NaN ; NaN ];
Tc_error_34  = [ NaN ; NaN ; NaN ];

%-- Image #35:
omc_35 = [ NaN ; NaN ; NaN ];
Tc_35  = [ NaN ; NaN ; NaN ];
omc_error_35 = [ NaN ; NaN ; NaN ];
Tc_error_35  = [ NaN ; NaN ; NaN ];

%-- Image #36:
omc_36 = [ NaN ; NaN ; NaN ];
Tc_36  = [ NaN ; NaN ; NaN ];
omc_error_36 = [ NaN ; NaN ; NaN ];
Tc_error_36  = [ NaN ; NaN ; NaN ];

%-- Image #37:
omc_37 = [ NaN ; NaN ; NaN ];
Tc_37  = [ NaN ; NaN ; NaN ];
omc_error_37 = [ NaN ; NaN ; NaN ];
Tc_error_37  = [ NaN ; NaN ; NaN ];

%-- Image #38:
omc_38 = [ NaN ; NaN ; NaN ];
Tc_38  = [ NaN ; NaN ; NaN ];
omc_error_38 = [ NaN ; NaN ; NaN ];
Tc_error_38  = [ NaN ; NaN ; NaN ];

%-- Image #39:
omc_39 = [ NaN ; NaN ; NaN ];
Tc_39  = [ NaN ; NaN ; NaN ];
omc_error_39 = [ NaN ; NaN ; NaN ];
Tc_error_39  = [ NaN ; NaN ; NaN ];

%-- Image #40:
omc_40 = [ NaN ; NaN ; NaN ];
Tc_40  = [ NaN ; NaN ; NaN ];
omc_error_40 = [ NaN ; NaN ; NaN ];
Tc_error_40  = [ NaN ; NaN ; NaN ];

%-- Image #41:
omc_41 = [ NaN ; NaN ; NaN ];
Tc_41  = [ NaN ; NaN ; NaN ];
omc_error_41 = [ NaN ; NaN ; NaN ];
Tc_error_41  = [ NaN ; NaN ; NaN ];

%-- Image #42:
omc_42 = [ NaN ; NaN ; NaN ];
Tc_42  = [ NaN ; NaN ; NaN ];
omc_error_42 = [ NaN ; NaN ; NaN ];
Tc_error_42  = [ NaN ; NaN ; NaN ];

%-- Image #43:
omc_43 = [ NaN ; NaN ; NaN ];
Tc_43  = [ NaN ; NaN ; NaN ];
omc_error_43 = [ NaN ; NaN ; NaN ];
Tc_error_43  = [ NaN ; NaN ; NaN ];

%-- Image #44:
omc_44 = [ NaN ; NaN ; NaN ];
Tc_44  = [ NaN ; NaN ; NaN ];
omc_error_44 = [ NaN ; NaN ; NaN ];
Tc_error_44  = [ NaN ; NaN ; NaN ];

%-- Image #45:
omc_45 = [ NaN ; NaN ; NaN ];
Tc_45  = [ NaN ; NaN ; NaN ];
omc_error_45 = [ NaN ; NaN ; NaN ];
Tc_error_45  = [ NaN ; NaN ; NaN ];

%-- Image #46:
omc_46 = [ NaN ; NaN ; NaN ];
Tc_46  = [ NaN ; NaN ; NaN ];
omc_error_46 = [ NaN ; NaN ; NaN ];
Tc_error_46  = [ NaN ; NaN ; NaN ];

%-- Image #47:
omc_47 = [ NaN ; NaN ; NaN ];
Tc_47  = [ NaN ; NaN ; NaN ];
omc_error_47 = [ NaN ; NaN ; NaN ];
Tc_error_47  = [ NaN ; NaN ; NaN ];

%-- Image #48:
omc_48 = [ NaN ; NaN ; NaN ];
Tc_48  = [ NaN ; NaN ; NaN ];
omc_error_48 = [ NaN ; NaN ; NaN ];
Tc_error_48  = [ NaN ; NaN ; NaN ];

%-- Image #49:
omc_49 = [ NaN ; NaN ; NaN ];
Tc_49  = [ NaN ; NaN ; NaN ];
omc_error_49 = [ NaN ; NaN ; NaN ];
Tc_error_49  = [ NaN ; NaN ; NaN ];

%-- Image #50:
omc_50 = [ NaN ; NaN ; NaN ];
Tc_50  = [ NaN ; NaN ; NaN ];
omc_error_50 = [ NaN ; NaN ; NaN ];
Tc_error_50  = [ NaN ; NaN ; NaN ];

%-- Image #51:
omc_51 = [ NaN ; NaN ; NaN ];
Tc_51  = [ NaN ; NaN ; NaN ];
omc_error_51 = [ NaN ; NaN ; NaN ];
Tc_error_51  = [ NaN ; NaN ; NaN ];

%-- Image #52:
omc_52 = [ NaN ; NaN ; NaN ];
Tc_52  = [ NaN ; NaN ; NaN ];
omc_error_52 = [ NaN ; NaN ; NaN ];
Tc_error_52  = [ NaN ; NaN ; NaN ];

%-- Image #53:
omc_53 = [ NaN ; NaN ; NaN ];
Tc_53  = [ NaN ; NaN ; NaN ];
omc_error_53 = [ NaN ; NaN ; NaN ];
Tc_error_53  = [ NaN ; NaN ; NaN ];

%-- Image #54:
omc_54 = [ NaN ; NaN ; NaN ];
Tc_54  = [ NaN ; NaN ; NaN ];
omc_error_54 = [ NaN ; NaN ; NaN ];
Tc_error_54  = [ NaN ; NaN ; NaN ];

%-- Image #55:
omc_55 = [ NaN ; NaN ; NaN ];
Tc_55  = [ NaN ; NaN ; NaN ];
omc_error_55 = [ NaN ; NaN ; NaN ];
Tc_error_55  = [ NaN ; NaN ; NaN ];

%-- Image #56:
omc_56 = [ NaN ; NaN ; NaN ];
Tc_56  = [ NaN ; NaN ; NaN ];
omc_error_56 = [ NaN ; NaN ; NaN ];
Tc_error_56  = [ NaN ; NaN ; NaN ];

%-- Image #57:
omc_57 = [ NaN ; NaN ; NaN ];
Tc_57  = [ NaN ; NaN ; NaN ];
omc_error_57 = [ NaN ; NaN ; NaN ];
Tc_error_57  = [ NaN ; NaN ; NaN ];

%-- Image #58:
omc_58 = [ NaN ; NaN ; NaN ];
Tc_58  = [ NaN ; NaN ; NaN ];
omc_error_58 = [ NaN ; NaN ; NaN ];
Tc_error_58  = [ NaN ; NaN ; NaN ];

%-- Image #59:
omc_59 = [ NaN ; NaN ; NaN ];
Tc_59  = [ NaN ; NaN ; NaN ];
omc_error_59 = [ NaN ; NaN ; NaN ];
Tc_error_59  = [ NaN ; NaN ; NaN ];

%-- Image #60:
omc_60 = [ NaN ; NaN ; NaN ];
Tc_60  = [ NaN ; NaN ; NaN ];
omc_error_60 = [ NaN ; NaN ; NaN ];
Tc_error_60  = [ NaN ; NaN ; NaN ];

%-- Image #61:
omc_61 = [ NaN ; NaN ; NaN ];
Tc_61  = [ NaN ; NaN ; NaN ];
omc_error_61 = [ NaN ; NaN ; NaN ];
Tc_error_61  = [ NaN ; NaN ; NaN ];

%-- Image #62:
omc_62 = [ NaN ; NaN ; NaN ];
Tc_62  = [ NaN ; NaN ; NaN ];
omc_error_62 = [ NaN ; NaN ; NaN ];
Tc_error_62  = [ NaN ; NaN ; NaN ];

%-- Image #63:
omc_63 = [ NaN ; NaN ; NaN ];
Tc_63  = [ NaN ; NaN ; NaN ];
omc_error_63 = [ NaN ; NaN ; NaN ];
Tc_error_63  = [ NaN ; NaN ; NaN ];

%-- Image #64:
omc_64 = [ NaN ; NaN ; NaN ];
Tc_64  = [ NaN ; NaN ; NaN ];
omc_error_64 = [ NaN ; NaN ; NaN ];
Tc_error_64  = [ NaN ; NaN ; NaN ];

%-- Image #65:
omc_65 = [ NaN ; NaN ; NaN ];
Tc_65  = [ NaN ; NaN ; NaN ];
omc_error_65 = [ NaN ; NaN ; NaN ];
Tc_error_65  = [ NaN ; NaN ; NaN ];

%-- Image #66:
omc_66 = [ NaN ; NaN ; NaN ];
Tc_66  = [ NaN ; NaN ; NaN ];
omc_error_66 = [ NaN ; NaN ; NaN ];
Tc_error_66  = [ NaN ; NaN ; NaN ];

%-- Image #67:
omc_67 = [ NaN ; NaN ; NaN ];
Tc_67  = [ NaN ; NaN ; NaN ];
omc_error_67 = [ NaN ; NaN ; NaN ];
Tc_error_67  = [ NaN ; NaN ; NaN ];

%-- Image #68:
omc_68 = [ NaN ; NaN ; NaN ];
Tc_68  = [ NaN ; NaN ; NaN ];
omc_error_68 = [ NaN ; NaN ; NaN ];
Tc_error_68  = [ NaN ; NaN ; NaN ];

%-- Image #69:
omc_69 = [ NaN ; NaN ; NaN ];
Tc_69  = [ NaN ; NaN ; NaN ];
omc_error_69 = [ NaN ; NaN ; NaN ];
Tc_error_69  = [ NaN ; NaN ; NaN ];

%-- Image #70:
omc_70 = [ NaN ; NaN ; NaN ];
Tc_70  = [ NaN ; NaN ; NaN ];
omc_error_70 = [ NaN ; NaN ; NaN ];
Tc_error_70  = [ NaN ; NaN ; NaN ];

%-- Image #71:
omc_71 = [ NaN ; NaN ; NaN ];
Tc_71  = [ NaN ; NaN ; NaN ];
omc_error_71 = [ NaN ; NaN ; NaN ];
Tc_error_71  = [ NaN ; NaN ; NaN ];

%-- Image #72:
omc_72 = [ NaN ; NaN ; NaN ];
Tc_72  = [ NaN ; NaN ; NaN ];
omc_error_72 = [ NaN ; NaN ; NaN ];
Tc_error_72  = [ NaN ; NaN ; NaN ];

%-- Image #73:
omc_73 = [ NaN ; NaN ; NaN ];
Tc_73  = [ NaN ; NaN ; NaN ];
omc_error_73 = [ NaN ; NaN ; NaN ];
Tc_error_73  = [ NaN ; NaN ; NaN ];

%-- Image #74:
omc_74 = [ NaN ; NaN ; NaN ];
Tc_74  = [ NaN ; NaN ; NaN ];
omc_error_74 = [ NaN ; NaN ; NaN ];
Tc_error_74  = [ NaN ; NaN ; NaN ];

%-- Image #75:
omc_75 = [ NaN ; NaN ; NaN ];
Tc_75  = [ NaN ; NaN ; NaN ];
omc_error_75 = [ NaN ; NaN ; NaN ];
Tc_error_75  = [ NaN ; NaN ; NaN ];

%-- Image #76:
omc_76 = [ NaN ; NaN ; NaN ];
Tc_76  = [ NaN ; NaN ; NaN ];
omc_error_76 = [ NaN ; NaN ; NaN ];
Tc_error_76  = [ NaN ; NaN ; NaN ];

%-- Image #77:
omc_77 = [ NaN ; NaN ; NaN ];
Tc_77  = [ NaN ; NaN ; NaN ];
omc_error_77 = [ NaN ; NaN ; NaN ];
Tc_error_77  = [ NaN ; NaN ; NaN ];

%-- Image #78:
omc_78 = [ NaN ; NaN ; NaN ];
Tc_78  = [ NaN ; NaN ; NaN ];
omc_error_78 = [ NaN ; NaN ; NaN ];
Tc_error_78  = [ NaN ; NaN ; NaN ];

%-- Image #79:
omc_79 = [ NaN ; NaN ; NaN ];
Tc_79  = [ NaN ; NaN ; NaN ];
omc_error_79 = [ NaN ; NaN ; NaN ];
Tc_error_79  = [ NaN ; NaN ; NaN ];

%-- Image #80:
omc_80 = [ NaN ; NaN ; NaN ];
Tc_80  = [ NaN ; NaN ; NaN ];
omc_error_80 = [ NaN ; NaN ; NaN ];
Tc_error_80  = [ NaN ; NaN ; NaN ];

%-- Image #81:
omc_81 = [ NaN ; NaN ; NaN ];
Tc_81  = [ NaN ; NaN ; NaN ];
omc_error_81 = [ NaN ; NaN ; NaN ];
Tc_error_81  = [ NaN ; NaN ; NaN ];

%-- Image #82:
omc_82 = [ NaN ; NaN ; NaN ];
Tc_82  = [ NaN ; NaN ; NaN ];
omc_error_82 = [ NaN ; NaN ; NaN ];
Tc_error_82  = [ NaN ; NaN ; NaN ];

%-- Image #83:
omc_83 = [ NaN ; NaN ; NaN ];
Tc_83  = [ NaN ; NaN ; NaN ];
omc_error_83 = [ NaN ; NaN ; NaN ];
Tc_error_83  = [ NaN ; NaN ; NaN ];

%-- Image #84:
omc_84 = [ NaN ; NaN ; NaN ];
Tc_84  = [ NaN ; NaN ; NaN ];
omc_error_84 = [ NaN ; NaN ; NaN ];
Tc_error_84  = [ NaN ; NaN ; NaN ];

%-- Image #85:
omc_85 = [ NaN ; NaN ; NaN ];
Tc_85  = [ NaN ; NaN ; NaN ];
omc_error_85 = [ NaN ; NaN ; NaN ];
Tc_error_85  = [ NaN ; NaN ; NaN ];

%-- Image #86:
omc_86 = [ NaN ; NaN ; NaN ];
Tc_86  = [ NaN ; NaN ; NaN ];
omc_error_86 = [ NaN ; NaN ; NaN ];
Tc_error_86  = [ NaN ; NaN ; NaN ];

%-- Image #87:
omc_87 = [ NaN ; NaN ; NaN ];
Tc_87  = [ NaN ; NaN ; NaN ];
omc_error_87 = [ NaN ; NaN ; NaN ];
Tc_error_87  = [ NaN ; NaN ; NaN ];

%-- Image #88:
omc_88 = [ NaN ; NaN ; NaN ];
Tc_88  = [ NaN ; NaN ; NaN ];
omc_error_88 = [ NaN ; NaN ; NaN ];
Tc_error_88  = [ NaN ; NaN ; NaN ];

%-- Image #89:
omc_89 = [ NaN ; NaN ; NaN ];
Tc_89  = [ NaN ; NaN ; NaN ];
omc_error_89 = [ NaN ; NaN ; NaN ];
Tc_error_89  = [ NaN ; NaN ; NaN ];

%-- Image #90:
omc_90 = [ NaN ; NaN ; NaN ];
Tc_90  = [ NaN ; NaN ; NaN ];
omc_error_90 = [ NaN ; NaN ; NaN ];
Tc_error_90  = [ NaN ; NaN ; NaN ];

%-- Image #91:
omc_91 = [ NaN ; NaN ; NaN ];
Tc_91  = [ NaN ; NaN ; NaN ];
omc_error_91 = [ NaN ; NaN ; NaN ];
Tc_error_91  = [ NaN ; NaN ; NaN ];

%-- Image #92:
omc_92 = [ NaN ; NaN ; NaN ];
Tc_92  = [ NaN ; NaN ; NaN ];
omc_error_92 = [ NaN ; NaN ; NaN ];
Tc_error_92  = [ NaN ; NaN ; NaN ];

%-- Image #93:
omc_93 = [ NaN ; NaN ; NaN ];
Tc_93  = [ NaN ; NaN ; NaN ];
omc_error_93 = [ NaN ; NaN ; NaN ];
Tc_error_93  = [ NaN ; NaN ; NaN ];

%-- Image #94:
omc_94 = [ NaN ; NaN ; NaN ];
Tc_94  = [ NaN ; NaN ; NaN ];
omc_error_94 = [ NaN ; NaN ; NaN ];
Tc_error_94  = [ NaN ; NaN ; NaN ];

%-- Image #95:
omc_95 = [ NaN ; NaN ; NaN ];
Tc_95  = [ NaN ; NaN ; NaN ];
omc_error_95 = [ NaN ; NaN ; NaN ];
Tc_error_95  = [ NaN ; NaN ; NaN ];

%-- Image #96:
omc_96 = [ NaN ; NaN ; NaN ];
Tc_96  = [ NaN ; NaN ; NaN ];
omc_error_96 = [ NaN ; NaN ; NaN ];
Tc_error_96  = [ NaN ; NaN ; NaN ];

%-- Image #97:
omc_97 = [ NaN ; NaN ; NaN ];
Tc_97  = [ NaN ; NaN ; NaN ];
omc_error_97 = [ NaN ; NaN ; NaN ];
Tc_error_97  = [ NaN ; NaN ; NaN ];

%-- Image #98:
omc_98 = [ NaN ; NaN ; NaN ];
Tc_98  = [ NaN ; NaN ; NaN ];
omc_error_98 = [ NaN ; NaN ; NaN ];
Tc_error_98  = [ NaN ; NaN ; NaN ];

%-- Image #99:
omc_99 = [ NaN ; NaN ; NaN ];
Tc_99  = [ NaN ; NaN ; NaN ];
omc_error_99 = [ NaN ; NaN ; NaN ];
Tc_error_99  = [ NaN ; NaN ; NaN ];

%-- Image #100:
omc_100 = [ NaN ; NaN ; NaN ];
Tc_100  = [ NaN ; NaN ; NaN ];
omc_error_100 = [ NaN ; NaN ; NaN ];
Tc_error_100  = [ NaN ; NaN ; NaN ];

%-- Image #101:
omc_101 = [ NaN ; NaN ; NaN ];
Tc_101  = [ NaN ; NaN ; NaN ];
omc_error_101 = [ NaN ; NaN ; NaN ];
Tc_error_101  = [ NaN ; NaN ; NaN ];

%-- Image #102:
omc_102 = [ NaN ; NaN ; NaN ];
Tc_102  = [ NaN ; NaN ; NaN ];
omc_error_102 = [ NaN ; NaN ; NaN ];
Tc_error_102  = [ NaN ; NaN ; NaN ];

%-- Image #103:
omc_103 = [ NaN ; NaN ; NaN ];
Tc_103  = [ NaN ; NaN ; NaN ];
omc_error_103 = [ NaN ; NaN ; NaN ];
Tc_error_103  = [ NaN ; NaN ; NaN ];

%-- Image #104:
omc_104 = [ NaN ; NaN ; NaN ];
Tc_104  = [ NaN ; NaN ; NaN ];
omc_error_104 = [ NaN ; NaN ; NaN ];
Tc_error_104  = [ NaN ; NaN ; NaN ];

%-- Image #105:
omc_105 = [ NaN ; NaN ; NaN ];
Tc_105  = [ NaN ; NaN ; NaN ];
omc_error_105 = [ NaN ; NaN ; NaN ];
Tc_error_105  = [ NaN ; NaN ; NaN ];

%-- Image #106:
omc_106 = [ NaN ; NaN ; NaN ];
Tc_106  = [ NaN ; NaN ; NaN ];
omc_error_106 = [ NaN ; NaN ; NaN ];
Tc_error_106  = [ NaN ; NaN ; NaN ];

%-- Image #107:
omc_107 = [ NaN ; NaN ; NaN ];
Tc_107  = [ NaN ; NaN ; NaN ];
omc_error_107 = [ NaN ; NaN ; NaN ];
Tc_error_107  = [ NaN ; NaN ; NaN ];

%-- Image #108:
omc_108 = [ NaN ; NaN ; NaN ];
Tc_108  = [ NaN ; NaN ; NaN ];
omc_error_108 = [ NaN ; NaN ; NaN ];
Tc_error_108  = [ NaN ; NaN ; NaN ];

%-- Image #109:
omc_109 = [ NaN ; NaN ; NaN ];
Tc_109  = [ NaN ; NaN ; NaN ];
omc_error_109 = [ NaN ; NaN ; NaN ];
Tc_error_109  = [ NaN ; NaN ; NaN ];

%-- Image #110:
omc_110 = [ NaN ; NaN ; NaN ];
Tc_110  = [ NaN ; NaN ; NaN ];
omc_error_110 = [ NaN ; NaN ; NaN ];
Tc_error_110  = [ NaN ; NaN ; NaN ];

%-- Image #111:
omc_111 = [ NaN ; NaN ; NaN ];
Tc_111  = [ NaN ; NaN ; NaN ];
omc_error_111 = [ NaN ; NaN ; NaN ];
Tc_error_111  = [ NaN ; NaN ; NaN ];

%-- Image #112:
omc_112 = [ NaN ; NaN ; NaN ];
Tc_112  = [ NaN ; NaN ; NaN ];
omc_error_112 = [ NaN ; NaN ; NaN ];
Tc_error_112  = [ NaN ; NaN ; NaN ];

%-- Image #113:
omc_113 = [ NaN ; NaN ; NaN ];
Tc_113  = [ NaN ; NaN ; NaN ];
omc_error_113 = [ NaN ; NaN ; NaN ];
Tc_error_113  = [ NaN ; NaN ; NaN ];

%-- Image #114:
omc_114 = [ NaN ; NaN ; NaN ];
Tc_114  = [ NaN ; NaN ; NaN ];
omc_error_114 = [ NaN ; NaN ; NaN ];
Tc_error_114  = [ NaN ; NaN ; NaN ];

%-- Image #115:
omc_115 = [ NaN ; NaN ; NaN ];
Tc_115  = [ NaN ; NaN ; NaN ];
omc_error_115 = [ NaN ; NaN ; NaN ];
Tc_error_115  = [ NaN ; NaN ; NaN ];

%-- Image #116:
omc_116 = [ NaN ; NaN ; NaN ];
Tc_116  = [ NaN ; NaN ; NaN ];
omc_error_116 = [ NaN ; NaN ; NaN ];
Tc_error_116  = [ NaN ; NaN ; NaN ];

%-- Image #117:
omc_117 = [ NaN ; NaN ; NaN ];
Tc_117  = [ NaN ; NaN ; NaN ];
omc_error_117 = [ NaN ; NaN ; NaN ];
Tc_error_117  = [ NaN ; NaN ; NaN ];

%-- Image #118:
omc_118 = [ NaN ; NaN ; NaN ];
Tc_118  = [ NaN ; NaN ; NaN ];
omc_error_118 = [ NaN ; NaN ; NaN ];
Tc_error_118  = [ NaN ; NaN ; NaN ];

%-- Image #119:
omc_119 = [ NaN ; NaN ; NaN ];
Tc_119  = [ NaN ; NaN ; NaN ];
omc_error_119 = [ NaN ; NaN ; NaN ];
Tc_error_119  = [ NaN ; NaN ; NaN ];

%-- Image #120:
omc_120 = [ NaN ; NaN ; NaN ];
Tc_120  = [ NaN ; NaN ; NaN ];
omc_error_120 = [ NaN ; NaN ; NaN ];
Tc_error_120  = [ NaN ; NaN ; NaN ];

%-- Image #121:
omc_121 = [ NaN ; NaN ; NaN ];
Tc_121  = [ NaN ; NaN ; NaN ];
omc_error_121 = [ NaN ; NaN ; NaN ];
Tc_error_121  = [ NaN ; NaN ; NaN ];

%-- Image #122:
omc_122 = [ NaN ; NaN ; NaN ];
Tc_122  = [ NaN ; NaN ; NaN ];
omc_error_122 = [ NaN ; NaN ; NaN ];
Tc_error_122  = [ NaN ; NaN ; NaN ];

%-- Image #123:
omc_123 = [ NaN ; NaN ; NaN ];
Tc_123  = [ NaN ; NaN ; NaN ];
omc_error_123 = [ NaN ; NaN ; NaN ];
Tc_error_123  = [ NaN ; NaN ; NaN ];

%-- Image #124:
omc_124 = [ NaN ; NaN ; NaN ];
Tc_124  = [ NaN ; NaN ; NaN ];
omc_error_124 = [ NaN ; NaN ; NaN ];
Tc_error_124  = [ NaN ; NaN ; NaN ];

%-- Image #125:
omc_125 = [ NaN ; NaN ; NaN ];
Tc_125  = [ NaN ; NaN ; NaN ];
omc_error_125 = [ NaN ; NaN ; NaN ];
Tc_error_125  = [ NaN ; NaN ; NaN ];

%-- Image #126:
omc_126 = [ NaN ; NaN ; NaN ];
Tc_126  = [ NaN ; NaN ; NaN ];
omc_error_126 = [ NaN ; NaN ; NaN ];
Tc_error_126  = [ NaN ; NaN ; NaN ];

%-- Image #127:
omc_127 = [ NaN ; NaN ; NaN ];
Tc_127  = [ NaN ; NaN ; NaN ];
omc_error_127 = [ NaN ; NaN ; NaN ];
Tc_error_127  = [ NaN ; NaN ; NaN ];

%-- Image #128:
omc_128 = [ NaN ; NaN ; NaN ];
Tc_128  = [ NaN ; NaN ; NaN ];
omc_error_128 = [ NaN ; NaN ; NaN ];
Tc_error_128  = [ NaN ; NaN ; NaN ];

%-- Image #129:
omc_129 = [ NaN ; NaN ; NaN ];
Tc_129  = [ NaN ; NaN ; NaN ];
omc_error_129 = [ NaN ; NaN ; NaN ];
Tc_error_129  = [ NaN ; NaN ; NaN ];

%-- Image #130:
omc_130 = [ NaN ; NaN ; NaN ];
Tc_130  = [ NaN ; NaN ; NaN ];
omc_error_130 = [ NaN ; NaN ; NaN ];
Tc_error_130  = [ NaN ; NaN ; NaN ];

%-- Image #131:
omc_131 = [ NaN ; NaN ; NaN ];
Tc_131  = [ NaN ; NaN ; NaN ];
omc_error_131 = [ NaN ; NaN ; NaN ];
Tc_error_131  = [ NaN ; NaN ; NaN ];

%-- Image #132:
omc_132 = [ NaN ; NaN ; NaN ];
Tc_132  = [ NaN ; NaN ; NaN ];
omc_error_132 = [ NaN ; NaN ; NaN ];
Tc_error_132  = [ NaN ; NaN ; NaN ];

%-- Image #133:
omc_133 = [ NaN ; NaN ; NaN ];
Tc_133  = [ NaN ; NaN ; NaN ];
omc_error_133 = [ NaN ; NaN ; NaN ];
Tc_error_133  = [ NaN ; NaN ; NaN ];

%-- Image #134:
omc_134 = [ NaN ; NaN ; NaN ];
Tc_134  = [ NaN ; NaN ; NaN ];
omc_error_134 = [ NaN ; NaN ; NaN ];
Tc_error_134  = [ NaN ; NaN ; NaN ];

%-- Image #135:
omc_135 = [ NaN ; NaN ; NaN ];
Tc_135  = [ NaN ; NaN ; NaN ];
omc_error_135 = [ NaN ; NaN ; NaN ];
Tc_error_135  = [ NaN ; NaN ; NaN ];

%-- Image #136:
omc_136 = [ NaN ; NaN ; NaN ];
Tc_136  = [ NaN ; NaN ; NaN ];
omc_error_136 = [ NaN ; NaN ; NaN ];
Tc_error_136  = [ NaN ; NaN ; NaN ];

%-- Image #137:
omc_137 = [ NaN ; NaN ; NaN ];
Tc_137  = [ NaN ; NaN ; NaN ];
omc_error_137 = [ NaN ; NaN ; NaN ];
Tc_error_137  = [ NaN ; NaN ; NaN ];

%-- Image #138:
omc_138 = [ NaN ; NaN ; NaN ];
Tc_138  = [ NaN ; NaN ; NaN ];
omc_error_138 = [ NaN ; NaN ; NaN ];
Tc_error_138  = [ NaN ; NaN ; NaN ];

%-- Image #139:
omc_139 = [ NaN ; NaN ; NaN ];
Tc_139  = [ NaN ; NaN ; NaN ];
omc_error_139 = [ NaN ; NaN ; NaN ];
Tc_error_139  = [ NaN ; NaN ; NaN ];

%-- Image #140:
omc_140 = [ NaN ; NaN ; NaN ];
Tc_140  = [ NaN ; NaN ; NaN ];
omc_error_140 = [ NaN ; NaN ; NaN ];
Tc_error_140  = [ NaN ; NaN ; NaN ];

%-- Image #141:
omc_141 = [ NaN ; NaN ; NaN ];
Tc_141  = [ NaN ; NaN ; NaN ];
omc_error_141 = [ NaN ; NaN ; NaN ];
Tc_error_141  = [ NaN ; NaN ; NaN ];

%-- Image #142:
omc_142 = [ NaN ; NaN ; NaN ];
Tc_142  = [ NaN ; NaN ; NaN ];
omc_error_142 = [ NaN ; NaN ; NaN ];
Tc_error_142  = [ NaN ; NaN ; NaN ];

%-- Image #143:
omc_143 = [ NaN ; NaN ; NaN ];
Tc_143  = [ NaN ; NaN ; NaN ];
omc_error_143 = [ NaN ; NaN ; NaN ];
Tc_error_143  = [ NaN ; NaN ; NaN ];

%-- Image #144:
omc_144 = [ NaN ; NaN ; NaN ];
Tc_144  = [ NaN ; NaN ; NaN ];
omc_error_144 = [ NaN ; NaN ; NaN ];
Tc_error_144  = [ NaN ; NaN ; NaN ];

%-- Image #145:
omc_145 = [ NaN ; NaN ; NaN ];
Tc_145  = [ NaN ; NaN ; NaN ];
omc_error_145 = [ NaN ; NaN ; NaN ];
Tc_error_145  = [ NaN ; NaN ; NaN ];

%-- Image #146:
omc_146 = [ NaN ; NaN ; NaN ];
Tc_146  = [ NaN ; NaN ; NaN ];
omc_error_146 = [ NaN ; NaN ; NaN ];
Tc_error_146  = [ NaN ; NaN ; NaN ];

%-- Image #147:
omc_147 = [ NaN ; NaN ; NaN ];
Tc_147  = [ NaN ; NaN ; NaN ];
omc_error_147 = [ NaN ; NaN ; NaN ];
Tc_error_147  = [ NaN ; NaN ; NaN ];

%-- Image #148:
omc_148 = [ NaN ; NaN ; NaN ];
Tc_148  = [ NaN ; NaN ; NaN ];
omc_error_148 = [ NaN ; NaN ; NaN ];
Tc_error_148  = [ NaN ; NaN ; NaN ];

%-- Image #149:
omc_149 = [ NaN ; NaN ; NaN ];
Tc_149  = [ NaN ; NaN ; NaN ];
omc_error_149 = [ NaN ; NaN ; NaN ];
Tc_error_149  = [ NaN ; NaN ; NaN ];

%-- Image #150:
omc_150 = [ NaN ; NaN ; NaN ];
Tc_150  = [ NaN ; NaN ; NaN ];
omc_error_150 = [ NaN ; NaN ; NaN ];
Tc_error_150  = [ NaN ; NaN ; NaN ];

%-- Image #151:
omc_151 = [ NaN ; NaN ; NaN ];
Tc_151  = [ NaN ; NaN ; NaN ];
omc_error_151 = [ NaN ; NaN ; NaN ];
Tc_error_151  = [ NaN ; NaN ; NaN ];

%-- Image #152:
omc_152 = [ NaN ; NaN ; NaN ];
Tc_152  = [ NaN ; NaN ; NaN ];
omc_error_152 = [ NaN ; NaN ; NaN ];
Tc_error_152  = [ NaN ; NaN ; NaN ];

%-- Image #153:
omc_153 = [ NaN ; NaN ; NaN ];
Tc_153  = [ NaN ; NaN ; NaN ];
omc_error_153 = [ NaN ; NaN ; NaN ];
Tc_error_153  = [ NaN ; NaN ; NaN ];

%-- Image #154:
omc_154 = [ NaN ; NaN ; NaN ];
Tc_154  = [ NaN ; NaN ; NaN ];
omc_error_154 = [ NaN ; NaN ; NaN ];
Tc_error_154  = [ NaN ; NaN ; NaN ];

%-- Image #155:
omc_155 = [ NaN ; NaN ; NaN ];
Tc_155  = [ NaN ; NaN ; NaN ];
omc_error_155 = [ NaN ; NaN ; NaN ];
Tc_error_155  = [ NaN ; NaN ; NaN ];

%-- Image #156:
omc_156 = [ NaN ; NaN ; NaN ];
Tc_156  = [ NaN ; NaN ; NaN ];
omc_error_156 = [ NaN ; NaN ; NaN ];
Tc_error_156  = [ NaN ; NaN ; NaN ];

%-- Image #157:
omc_157 = [ NaN ; NaN ; NaN ];
Tc_157  = [ NaN ; NaN ; NaN ];
omc_error_157 = [ NaN ; NaN ; NaN ];
Tc_error_157  = [ NaN ; NaN ; NaN ];

%-- Image #158:
omc_158 = [ NaN ; NaN ; NaN ];
Tc_158  = [ NaN ; NaN ; NaN ];
omc_error_158 = [ NaN ; NaN ; NaN ];
Tc_error_158  = [ NaN ; NaN ; NaN ];

%-- Image #159:
omc_159 = [ NaN ; NaN ; NaN ];
Tc_159  = [ NaN ; NaN ; NaN ];
omc_error_159 = [ NaN ; NaN ; NaN ];
Tc_error_159  = [ NaN ; NaN ; NaN ];

%-- Image #160:
omc_160 = [ NaN ; NaN ; NaN ];
Tc_160  = [ NaN ; NaN ; NaN ];
omc_error_160 = [ NaN ; NaN ; NaN ];
Tc_error_160  = [ NaN ; NaN ; NaN ];

%-- Image #161:
omc_161 = [ NaN ; NaN ; NaN ];
Tc_161  = [ NaN ; NaN ; NaN ];
omc_error_161 = [ NaN ; NaN ; NaN ];
Tc_error_161  = [ NaN ; NaN ; NaN ];

%-- Image #162:
omc_162 = [ NaN ; NaN ; NaN ];
Tc_162  = [ NaN ; NaN ; NaN ];
omc_error_162 = [ NaN ; NaN ; NaN ];
Tc_error_162  = [ NaN ; NaN ; NaN ];

%-- Image #163:
omc_163 = [ NaN ; NaN ; NaN ];
Tc_163  = [ NaN ; NaN ; NaN ];
omc_error_163 = [ NaN ; NaN ; NaN ];
Tc_error_163  = [ NaN ; NaN ; NaN ];

%-- Image #164:
omc_164 = [ NaN ; NaN ; NaN ];
Tc_164  = [ NaN ; NaN ; NaN ];
omc_error_164 = [ NaN ; NaN ; NaN ];
Tc_error_164  = [ NaN ; NaN ; NaN ];

%-- Image #165:
omc_165 = [ NaN ; NaN ; NaN ];
Tc_165  = [ NaN ; NaN ; NaN ];
omc_error_165 = [ NaN ; NaN ; NaN ];
Tc_error_165  = [ NaN ; NaN ; NaN ];

%-- Image #166:
omc_166 = [ NaN ; NaN ; NaN ];
Tc_166  = [ NaN ; NaN ; NaN ];
omc_error_166 = [ NaN ; NaN ; NaN ];
Tc_error_166  = [ NaN ; NaN ; NaN ];

%-- Image #167:
omc_167 = [ NaN ; NaN ; NaN ];
Tc_167  = [ NaN ; NaN ; NaN ];
omc_error_167 = [ NaN ; NaN ; NaN ];
Tc_error_167  = [ NaN ; NaN ; NaN ];

%-- Image #168:
omc_168 = [ NaN ; NaN ; NaN ];
Tc_168  = [ NaN ; NaN ; NaN ];
omc_error_168 = [ NaN ; NaN ; NaN ];
Tc_error_168  = [ NaN ; NaN ; NaN ];

%-- Image #169:
omc_169 = [ NaN ; NaN ; NaN ];
Tc_169  = [ NaN ; NaN ; NaN ];
omc_error_169 = [ NaN ; NaN ; NaN ];
Tc_error_169  = [ NaN ; NaN ; NaN ];

%-- Image #170:
omc_170 = [ NaN ; NaN ; NaN ];
Tc_170  = [ NaN ; NaN ; NaN ];
omc_error_170 = [ NaN ; NaN ; NaN ];
Tc_error_170  = [ NaN ; NaN ; NaN ];

%-- Image #171:
omc_171 = [ NaN ; NaN ; NaN ];
Tc_171  = [ NaN ; NaN ; NaN ];
omc_error_171 = [ NaN ; NaN ; NaN ];
Tc_error_171  = [ NaN ; NaN ; NaN ];

%-- Image #172:
omc_172 = [ NaN ; NaN ; NaN ];
Tc_172  = [ NaN ; NaN ; NaN ];
omc_error_172 = [ NaN ; NaN ; NaN ];
Tc_error_172  = [ NaN ; NaN ; NaN ];

%-- Image #173:
omc_173 = [ NaN ; NaN ; NaN ];
Tc_173  = [ NaN ; NaN ; NaN ];
omc_error_173 = [ NaN ; NaN ; NaN ];
Tc_error_173  = [ NaN ; NaN ; NaN ];

%-- Image #174:
omc_174 = [ NaN ; NaN ; NaN ];
Tc_174  = [ NaN ; NaN ; NaN ];
omc_error_174 = [ NaN ; NaN ; NaN ];
Tc_error_174  = [ NaN ; NaN ; NaN ];

%-- Image #175:
omc_175 = [ NaN ; NaN ; NaN ];
Tc_175  = [ NaN ; NaN ; NaN ];
omc_error_175 = [ NaN ; NaN ; NaN ];
Tc_error_175  = [ NaN ; NaN ; NaN ];

%-- Image #176:
omc_176 = [ NaN ; NaN ; NaN ];
Tc_176  = [ NaN ; NaN ; NaN ];
omc_error_176 = [ NaN ; NaN ; NaN ];
Tc_error_176  = [ NaN ; NaN ; NaN ];

%-- Image #177:
omc_177 = [ NaN ; NaN ; NaN ];
Tc_177  = [ NaN ; NaN ; NaN ];
omc_error_177 = [ NaN ; NaN ; NaN ];
Tc_error_177  = [ NaN ; NaN ; NaN ];

%-- Image #178:
omc_178 = [ NaN ; NaN ; NaN ];
Tc_178  = [ NaN ; NaN ; NaN ];
omc_error_178 = [ NaN ; NaN ; NaN ];
Tc_error_178  = [ NaN ; NaN ; NaN ];

%-- Image #179:
omc_179 = [ NaN ; NaN ; NaN ];
Tc_179  = [ NaN ; NaN ; NaN ];
omc_error_179 = [ NaN ; NaN ; NaN ];
Tc_error_179  = [ NaN ; NaN ; NaN ];

%-- Image #180:
omc_180 = [ NaN ; NaN ; NaN ];
Tc_180  = [ NaN ; NaN ; NaN ];
omc_error_180 = [ NaN ; NaN ; NaN ];
Tc_error_180  = [ NaN ; NaN ; NaN ];

%-- Image #181:
omc_181 = [ NaN ; NaN ; NaN ];
Tc_181  = [ NaN ; NaN ; NaN ];
omc_error_181 = [ NaN ; NaN ; NaN ];
Tc_error_181  = [ NaN ; NaN ; NaN ];

%-- Image #182:
omc_182 = [ NaN ; NaN ; NaN ];
Tc_182  = [ NaN ; NaN ; NaN ];
omc_error_182 = [ NaN ; NaN ; NaN ];
Tc_error_182  = [ NaN ; NaN ; NaN ];

%-- Image #183:
omc_183 = [ NaN ; NaN ; NaN ];
Tc_183  = [ NaN ; NaN ; NaN ];
omc_error_183 = [ NaN ; NaN ; NaN ];
Tc_error_183  = [ NaN ; NaN ; NaN ];

%-- Image #184:
omc_184 = [ NaN ; NaN ; NaN ];
Tc_184  = [ NaN ; NaN ; NaN ];
omc_error_184 = [ NaN ; NaN ; NaN ];
Tc_error_184  = [ NaN ; NaN ; NaN ];

%-- Image #185:
omc_185 = [ NaN ; NaN ; NaN ];
Tc_185  = [ NaN ; NaN ; NaN ];
omc_error_185 = [ NaN ; NaN ; NaN ];
Tc_error_185  = [ NaN ; NaN ; NaN ];

%-- Image #186:
omc_186 = [ NaN ; NaN ; NaN ];
Tc_186  = [ NaN ; NaN ; NaN ];
omc_error_186 = [ NaN ; NaN ; NaN ];
Tc_error_186  = [ NaN ; NaN ; NaN ];

%-- Image #187:
omc_187 = [ NaN ; NaN ; NaN ];
Tc_187  = [ NaN ; NaN ; NaN ];
omc_error_187 = [ NaN ; NaN ; NaN ];
Tc_error_187  = [ NaN ; NaN ; NaN ];

%-- Image #188:
omc_188 = [ NaN ; NaN ; NaN ];
Tc_188  = [ NaN ; NaN ; NaN ];
omc_error_188 = [ NaN ; NaN ; NaN ];
Tc_error_188  = [ NaN ; NaN ; NaN ];

%-- Image #189:
omc_189 = [ NaN ; NaN ; NaN ];
Tc_189  = [ NaN ; NaN ; NaN ];
omc_error_189 = [ NaN ; NaN ; NaN ];
Tc_error_189  = [ NaN ; NaN ; NaN ];

%-- Image #190:
omc_190 = [ NaN ; NaN ; NaN ];
Tc_190  = [ NaN ; NaN ; NaN ];
omc_error_190 = [ NaN ; NaN ; NaN ];
Tc_error_190  = [ NaN ; NaN ; NaN ];

%-- Image #191:
omc_191 = [ NaN ; NaN ; NaN ];
Tc_191  = [ NaN ; NaN ; NaN ];
omc_error_191 = [ NaN ; NaN ; NaN ];
Tc_error_191  = [ NaN ; NaN ; NaN ];

%-- Image #192:
omc_192 = [ NaN ; NaN ; NaN ];
Tc_192  = [ NaN ; NaN ; NaN ];
omc_error_192 = [ NaN ; NaN ; NaN ];
Tc_error_192  = [ NaN ; NaN ; NaN ];

%-- Image #193:
omc_193 = [ NaN ; NaN ; NaN ];
Tc_193  = [ NaN ; NaN ; NaN ];
omc_error_193 = [ NaN ; NaN ; NaN ];
Tc_error_193  = [ NaN ; NaN ; NaN ];

%-- Image #194:
omc_194 = [ NaN ; NaN ; NaN ];
Tc_194  = [ NaN ; NaN ; NaN ];
omc_error_194 = [ NaN ; NaN ; NaN ];
Tc_error_194  = [ NaN ; NaN ; NaN ];

%-- Image #195:
omc_195 = [ NaN ; NaN ; NaN ];
Tc_195  = [ NaN ; NaN ; NaN ];
omc_error_195 = [ NaN ; NaN ; NaN ];
Tc_error_195  = [ NaN ; NaN ; NaN ];

%-- Image #196:
omc_196 = [ NaN ; NaN ; NaN ];
Tc_196  = [ NaN ; NaN ; NaN ];
omc_error_196 = [ NaN ; NaN ; NaN ];
Tc_error_196  = [ NaN ; NaN ; NaN ];

%-- Image #197:
omc_197 = [ NaN ; NaN ; NaN ];
Tc_197  = [ NaN ; NaN ; NaN ];
omc_error_197 = [ NaN ; NaN ; NaN ];
Tc_error_197  = [ NaN ; NaN ; NaN ];

%-- Image #198:
omc_198 = [ NaN ; NaN ; NaN ];
Tc_198  = [ NaN ; NaN ; NaN ];
omc_error_198 = [ NaN ; NaN ; NaN ];
Tc_error_198  = [ NaN ; NaN ; NaN ];

%-- Image #199:
omc_199 = [ NaN ; NaN ; NaN ];
Tc_199  = [ NaN ; NaN ; NaN ];
omc_error_199 = [ NaN ; NaN ; NaN ];
Tc_error_199  = [ NaN ; NaN ; NaN ];

%-- Image #200:
omc_200 = [ NaN ; NaN ; NaN ];
Tc_200  = [ NaN ; NaN ; NaN ];
omc_error_200 = [ NaN ; NaN ; NaN ];
Tc_error_200  = [ NaN ; NaN ; NaN ];

%-- Image #201:
omc_201 = [ NaN ; NaN ; NaN ];
Tc_201  = [ NaN ; NaN ; NaN ];
omc_error_201 = [ NaN ; NaN ; NaN ];
Tc_error_201  = [ NaN ; NaN ; NaN ];

%-- Image #202:
omc_202 = [ NaN ; NaN ; NaN ];
Tc_202  = [ NaN ; NaN ; NaN ];
omc_error_202 = [ NaN ; NaN ; NaN ];
Tc_error_202  = [ NaN ; NaN ; NaN ];

%-- Image #203:
omc_203 = [ NaN ; NaN ; NaN ];
Tc_203  = [ NaN ; NaN ; NaN ];
omc_error_203 = [ NaN ; NaN ; NaN ];
Tc_error_203  = [ NaN ; NaN ; NaN ];

%-- Image #204:
omc_204 = [ NaN ; NaN ; NaN ];
Tc_204  = [ NaN ; NaN ; NaN ];
omc_error_204 = [ NaN ; NaN ; NaN ];
Tc_error_204  = [ NaN ; NaN ; NaN ];

%-- Image #205:
omc_205 = [ NaN ; NaN ; NaN ];
Tc_205  = [ NaN ; NaN ; NaN ];
omc_error_205 = [ NaN ; NaN ; NaN ];
Tc_error_205  = [ NaN ; NaN ; NaN ];

%-- Image #206:
omc_206 = [ NaN ; NaN ; NaN ];
Tc_206  = [ NaN ; NaN ; NaN ];
omc_error_206 = [ NaN ; NaN ; NaN ];
Tc_error_206  = [ NaN ; NaN ; NaN ];

%-- Image #207:
omc_207 = [ NaN ; NaN ; NaN ];
Tc_207  = [ NaN ; NaN ; NaN ];
omc_error_207 = [ NaN ; NaN ; NaN ];
Tc_error_207  = [ NaN ; NaN ; NaN ];

%-- Image #208:
omc_208 = [ NaN ; NaN ; NaN ];
Tc_208  = [ NaN ; NaN ; NaN ];
omc_error_208 = [ NaN ; NaN ; NaN ];
Tc_error_208  = [ NaN ; NaN ; NaN ];

%-- Image #209:
omc_209 = [ NaN ; NaN ; NaN ];
Tc_209  = [ NaN ; NaN ; NaN ];
omc_error_209 = [ NaN ; NaN ; NaN ];
Tc_error_209  = [ NaN ; NaN ; NaN ];

%-- Image #210:
omc_210 = [ NaN ; NaN ; NaN ];
Tc_210  = [ NaN ; NaN ; NaN ];
omc_error_210 = [ NaN ; NaN ; NaN ];
Tc_error_210  = [ NaN ; NaN ; NaN ];

%-- Image #211:
omc_211 = [ NaN ; NaN ; NaN ];
Tc_211  = [ NaN ; NaN ; NaN ];
omc_error_211 = [ NaN ; NaN ; NaN ];
Tc_error_211  = [ NaN ; NaN ; NaN ];

%-- Image #212:
omc_212 = [ NaN ; NaN ; NaN ];
Tc_212  = [ NaN ; NaN ; NaN ];
omc_error_212 = [ NaN ; NaN ; NaN ];
Tc_error_212  = [ NaN ; NaN ; NaN ];

%-- Image #213:
omc_213 = [ NaN ; NaN ; NaN ];
Tc_213  = [ NaN ; NaN ; NaN ];
omc_error_213 = [ NaN ; NaN ; NaN ];
Tc_error_213  = [ NaN ; NaN ; NaN ];

%-- Image #214:
omc_214 = [ NaN ; NaN ; NaN ];
Tc_214  = [ NaN ; NaN ; NaN ];
omc_error_214 = [ NaN ; NaN ; NaN ];
Tc_error_214  = [ NaN ; NaN ; NaN ];

%-- Image #215:
omc_215 = [ NaN ; NaN ; NaN ];
Tc_215  = [ NaN ; NaN ; NaN ];
omc_error_215 = [ NaN ; NaN ; NaN ];
Tc_error_215  = [ NaN ; NaN ; NaN ];

%-- Image #216:
omc_216 = [ NaN ; NaN ; NaN ];
Tc_216  = [ NaN ; NaN ; NaN ];
omc_error_216 = [ NaN ; NaN ; NaN ];
Tc_error_216  = [ NaN ; NaN ; NaN ];

%-- Image #217:
omc_217 = [ NaN ; NaN ; NaN ];
Tc_217  = [ NaN ; NaN ; NaN ];
omc_error_217 = [ NaN ; NaN ; NaN ];
Tc_error_217  = [ NaN ; NaN ; NaN ];

%-- Image #218:
omc_218 = [ NaN ; NaN ; NaN ];
Tc_218  = [ NaN ; NaN ; NaN ];
omc_error_218 = [ NaN ; NaN ; NaN ];
Tc_error_218  = [ NaN ; NaN ; NaN ];

%-- Image #219:
omc_219 = [ NaN ; NaN ; NaN ];
Tc_219  = [ NaN ; NaN ; NaN ];
omc_error_219 = [ NaN ; NaN ; NaN ];
Tc_error_219  = [ NaN ; NaN ; NaN ];

%-- Image #220:
omc_220 = [ NaN ; NaN ; NaN ];
Tc_220  = [ NaN ; NaN ; NaN ];
omc_error_220 = [ NaN ; NaN ; NaN ];
Tc_error_220  = [ NaN ; NaN ; NaN ];

%-- Image #221:
omc_221 = [ NaN ; NaN ; NaN ];
Tc_221  = [ NaN ; NaN ; NaN ];
omc_error_221 = [ NaN ; NaN ; NaN ];
Tc_error_221  = [ NaN ; NaN ; NaN ];

%-- Image #222:
omc_222 = [ NaN ; NaN ; NaN ];
Tc_222  = [ NaN ; NaN ; NaN ];
omc_error_222 = [ NaN ; NaN ; NaN ];
Tc_error_222  = [ NaN ; NaN ; NaN ];

%-- Image #223:
omc_223 = [ NaN ; NaN ; NaN ];
Tc_223  = [ NaN ; NaN ; NaN ];
omc_error_223 = [ NaN ; NaN ; NaN ];
Tc_error_223  = [ NaN ; NaN ; NaN ];

%-- Image #224:
omc_224 = [ NaN ; NaN ; NaN ];
Tc_224  = [ NaN ; NaN ; NaN ];
omc_error_224 = [ NaN ; NaN ; NaN ];
Tc_error_224  = [ NaN ; NaN ; NaN ];

%-- Image #225:
omc_225 = [ NaN ; NaN ; NaN ];
Tc_225  = [ NaN ; NaN ; NaN ];
omc_error_225 = [ NaN ; NaN ; NaN ];
Tc_error_225  = [ NaN ; NaN ; NaN ];

%-- Image #226:
omc_226 = [ NaN ; NaN ; NaN ];
Tc_226  = [ NaN ; NaN ; NaN ];
omc_error_226 = [ NaN ; NaN ; NaN ];
Tc_error_226  = [ NaN ; NaN ; NaN ];

%-- Image #227:
omc_227 = [ NaN ; NaN ; NaN ];
Tc_227  = [ NaN ; NaN ; NaN ];
omc_error_227 = [ NaN ; NaN ; NaN ];
Tc_error_227  = [ NaN ; NaN ; NaN ];

%-- Image #228:
omc_228 = [ NaN ; NaN ; NaN ];
Tc_228  = [ NaN ; NaN ; NaN ];
omc_error_228 = [ NaN ; NaN ; NaN ];
Tc_error_228  = [ NaN ; NaN ; NaN ];

%-- Image #229:
omc_229 = [ 2.983759e+00 ; 1.254122e-01 ; -1.225659e-01 ];
Tc_229  = [ 3.058652e+02 ; 3.263554e+02 ; 1.028238e+03 ];
omc_error_229 = [ 2.014389e-03 ; 1.615421e-03 ; 3.632981e-03 ];
Tc_error_229  = [ 2.724300e+00 ; 4.674044e+00 ; 5.132004e+00 ];

%-- Image #230:
omc_230 = [ NaN ; NaN ; NaN ];
Tc_230  = [ NaN ; NaN ; NaN ];
omc_error_230 = [ NaN ; NaN ; NaN ];
Tc_error_230  = [ NaN ; NaN ; NaN ];

%-- Image #231:
omc_231 = [ NaN ; NaN ; NaN ];
Tc_231  = [ NaN ; NaN ; NaN ];
omc_error_231 = [ NaN ; NaN ; NaN ];
Tc_error_231  = [ NaN ; NaN ; NaN ];

%-- Image #232:
omc_232 = [ NaN ; NaN ; NaN ];
Tc_232  = [ NaN ; NaN ; NaN ];
omc_error_232 = [ NaN ; NaN ; NaN ];
Tc_error_232  = [ NaN ; NaN ; NaN ];

%-- Image #233:
omc_233 = [ 3.056307e+00 ; -3.316636e-02 ; -1.640724e-01 ];
Tc_233  = [ 3.050954e+02 ; 1.790669e+02 ; 1.016163e+03 ];
omc_error_233 = [ 1.912757e-03 ; 1.756034e-03 ; 3.744234e-03 ];
Tc_error_233  = [ 2.457480e+00 ; 4.396252e+00 ; 5.094061e+00 ];

%-- Image #234:
omc_234 = [ NaN ; NaN ; NaN ];
Tc_234  = [ NaN ; NaN ; NaN ];
omc_error_234 = [ NaN ; NaN ; NaN ];
Tc_error_234  = [ NaN ; NaN ; NaN ];

%-- Image #235:
omc_235 = [ NaN ; NaN ; NaN ];
Tc_235  = [ NaN ; NaN ; NaN ];
omc_error_235 = [ NaN ; NaN ; NaN ];
Tc_error_235  = [ NaN ; NaN ; NaN ];

%-- Image #236:
omc_236 = [ NaN ; NaN ; NaN ];
Tc_236  = [ NaN ; NaN ; NaN ];
omc_error_236 = [ NaN ; NaN ; NaN ];
Tc_error_236  = [ NaN ; NaN ; NaN ];

%-- Image #237:
omc_237 = [ NaN ; NaN ; NaN ];
Tc_237  = [ NaN ; NaN ; NaN ];
omc_error_237 = [ NaN ; NaN ; NaN ];
Tc_error_237  = [ NaN ; NaN ; NaN ];

%-- Image #238:
omc_238 = [ NaN ; NaN ; NaN ];
Tc_238  = [ NaN ; NaN ; NaN ];
omc_error_238 = [ NaN ; NaN ; NaN ];
Tc_error_238  = [ NaN ; NaN ; NaN ];

%-- Image #239:
omc_239 = [ NaN ; NaN ; NaN ];
Tc_239  = [ NaN ; NaN ; NaN ];
omc_error_239 = [ NaN ; NaN ; NaN ];
Tc_error_239  = [ NaN ; NaN ; NaN ];

%-- Image #240:
omc_240 = [ NaN ; NaN ; NaN ];
Tc_240  = [ NaN ; NaN ; NaN ];
omc_error_240 = [ NaN ; NaN ; NaN ];
Tc_error_240  = [ NaN ; NaN ; NaN ];

%-- Image #241:
omc_241 = [ NaN ; NaN ; NaN ];
Tc_241  = [ NaN ; NaN ; NaN ];
omc_error_241 = [ NaN ; NaN ; NaN ];
Tc_error_241  = [ NaN ; NaN ; NaN ];

%-- Image #242:
omc_242 = [ NaN ; NaN ; NaN ];
Tc_242  = [ NaN ; NaN ; NaN ];
omc_error_242 = [ NaN ; NaN ; NaN ];
Tc_error_242  = [ NaN ; NaN ; NaN ];

%-- Image #243:
omc_243 = [ NaN ; NaN ; NaN ];
Tc_243  = [ NaN ; NaN ; NaN ];
omc_error_243 = [ NaN ; NaN ; NaN ];
Tc_error_243  = [ NaN ; NaN ; NaN ];

%-- Image #244:
omc_244 = [ NaN ; NaN ; NaN ];
Tc_244  = [ NaN ; NaN ; NaN ];
omc_error_244 = [ NaN ; NaN ; NaN ];
Tc_error_244  = [ NaN ; NaN ; NaN ];

%-- Image #245:
omc_245 = [ NaN ; NaN ; NaN ];
Tc_245  = [ NaN ; NaN ; NaN ];
omc_error_245 = [ NaN ; NaN ; NaN ];
Tc_error_245  = [ NaN ; NaN ; NaN ];

%-- Image #246:
omc_246 = [ NaN ; NaN ; NaN ];
Tc_246  = [ NaN ; NaN ; NaN ];
omc_error_246 = [ NaN ; NaN ; NaN ];
Tc_error_246  = [ NaN ; NaN ; NaN ];

%-- Image #247:
omc_247 = [ NaN ; NaN ; NaN ];
Tc_247  = [ NaN ; NaN ; NaN ];
omc_error_247 = [ NaN ; NaN ; NaN ];
Tc_error_247  = [ NaN ; NaN ; NaN ];

%-- Image #248:
omc_248 = [ NaN ; NaN ; NaN ];
Tc_248  = [ NaN ; NaN ; NaN ];
omc_error_248 = [ NaN ; NaN ; NaN ];
Tc_error_248  = [ NaN ; NaN ; NaN ];

%-- Image #249:
omc_249 = [ NaN ; NaN ; NaN ];
Tc_249  = [ NaN ; NaN ; NaN ];
omc_error_249 = [ NaN ; NaN ; NaN ];
Tc_error_249  = [ NaN ; NaN ; NaN ];

%-- Image #250:
omc_250 = [ NaN ; NaN ; NaN ];
Tc_250  = [ NaN ; NaN ; NaN ];
omc_error_250 = [ NaN ; NaN ; NaN ];
Tc_error_250  = [ NaN ; NaN ; NaN ];

%-- Image #251:
omc_251 = [ NaN ; NaN ; NaN ];
Tc_251  = [ NaN ; NaN ; NaN ];
omc_error_251 = [ NaN ; NaN ; NaN ];
Tc_error_251  = [ NaN ; NaN ; NaN ];

%-- Image #252:
omc_252 = [ NaN ; NaN ; NaN ];
Tc_252  = [ NaN ; NaN ; NaN ];
omc_error_252 = [ NaN ; NaN ; NaN ];
Tc_error_252  = [ NaN ; NaN ; NaN ];

%-- Image #253:
omc_253 = [ NaN ; NaN ; NaN ];
Tc_253  = [ NaN ; NaN ; NaN ];
omc_error_253 = [ NaN ; NaN ; NaN ];
Tc_error_253  = [ NaN ; NaN ; NaN ];

%-- Image #254:
omc_254 = [ NaN ; NaN ; NaN ];
Tc_254  = [ NaN ; NaN ; NaN ];
omc_error_254 = [ NaN ; NaN ; NaN ];
Tc_error_254  = [ NaN ; NaN ; NaN ];

%-- Image #255:
omc_255 = [ NaN ; NaN ; NaN ];
Tc_255  = [ NaN ; NaN ; NaN ];
omc_error_255 = [ NaN ; NaN ; NaN ];
Tc_error_255  = [ NaN ; NaN ; NaN ];

%-- Image #256:
omc_256 = [ NaN ; NaN ; NaN ];
Tc_256  = [ NaN ; NaN ; NaN ];
omc_error_256 = [ NaN ; NaN ; NaN ];
Tc_error_256  = [ NaN ; NaN ; NaN ];

%-- Image #257:
omc_257 = [ NaN ; NaN ; NaN ];
Tc_257  = [ NaN ; NaN ; NaN ];
omc_error_257 = [ NaN ; NaN ; NaN ];
Tc_error_257  = [ NaN ; NaN ; NaN ];

%-- Image #258:
omc_258 = [ NaN ; NaN ; NaN ];
Tc_258  = [ NaN ; NaN ; NaN ];
omc_error_258 = [ NaN ; NaN ; NaN ];
Tc_error_258  = [ NaN ; NaN ; NaN ];

%-- Image #259:
omc_259 = [ NaN ; NaN ; NaN ];
Tc_259  = [ NaN ; NaN ; NaN ];
omc_error_259 = [ NaN ; NaN ; NaN ];
Tc_error_259  = [ NaN ; NaN ; NaN ];

%-- Image #260:
omc_260 = [ NaN ; NaN ; NaN ];
Tc_260  = [ NaN ; NaN ; NaN ];
omc_error_260 = [ NaN ; NaN ; NaN ];
Tc_error_260  = [ NaN ; NaN ; NaN ];

%-- Image #261:
omc_261 = [ 2.963944e+00 ; -3.598713e-01 ; 1.469645e-01 ];
Tc_261  = [ -1.533391e+01 ; 8.476810e+01 ; 1.017999e+03 ];
omc_error_261 = [ 2.193931e-03 ; 1.837124e-03 ; 3.068808e-03 ];
Tc_error_261  = [ 2.584383e+00 ; 4.454643e+00 ; 5.018382e+00 ];

%-- Image #262:
omc_262 = [ NaN ; NaN ; NaN ];
Tc_262  = [ NaN ; NaN ; NaN ];
omc_error_262 = [ NaN ; NaN ; NaN ];
Tc_error_262  = [ NaN ; NaN ; NaN ];

%-- Image #263:
omc_263 = [ NaN ; NaN ; NaN ];
Tc_263  = [ NaN ; NaN ; NaN ];
omc_error_263 = [ NaN ; NaN ; NaN ];
Tc_error_263  = [ NaN ; NaN ; NaN ];

%-- Image #264:
omc_264 = [ NaN ; NaN ; NaN ];
Tc_264  = [ NaN ; NaN ; NaN ];
omc_error_264 = [ NaN ; NaN ; NaN ];
Tc_error_264  = [ NaN ; NaN ; NaN ];

%-- Image #265:
omc_265 = [ NaN ; NaN ; NaN ];
Tc_265  = [ NaN ; NaN ; NaN ];
omc_error_265 = [ NaN ; NaN ; NaN ];
Tc_error_265  = [ NaN ; NaN ; NaN ];

%-- Image #266:
omc_266 = [ NaN ; NaN ; NaN ];
Tc_266  = [ NaN ; NaN ; NaN ];
omc_error_266 = [ NaN ; NaN ; NaN ];
Tc_error_266  = [ NaN ; NaN ; NaN ];

%-- Image #267:
omc_267 = [ NaN ; NaN ; NaN ];
Tc_267  = [ NaN ; NaN ; NaN ];
omc_error_267 = [ NaN ; NaN ; NaN ];
Tc_error_267  = [ NaN ; NaN ; NaN ];

%-- Image #268:
omc_268 = [ NaN ; NaN ; NaN ];
Tc_268  = [ NaN ; NaN ; NaN ];
omc_error_268 = [ NaN ; NaN ; NaN ];
Tc_error_268  = [ NaN ; NaN ; NaN ];

%-- Image #269:
omc_269 = [ NaN ; NaN ; NaN ];
Tc_269  = [ NaN ; NaN ; NaN ];
omc_error_269 = [ NaN ; NaN ; NaN ];
Tc_error_269  = [ NaN ; NaN ; NaN ];

%-- Image #270:
omc_270 = [ NaN ; NaN ; NaN ];
Tc_270  = [ NaN ; NaN ; NaN ];
omc_error_270 = [ NaN ; NaN ; NaN ];
Tc_error_270  = [ NaN ; NaN ; NaN ];

%-- Image #271:
omc_271 = [ 2.740726e+00 ; -4.640549e-01 ; 5.280314e-01 ];
Tc_271  = [ -3.361207e+02 ; 3.463572e+02 ; 9.642988e+02 ];
omc_error_271 = [ 3.171965e-03 ; 2.111779e-03 ; 3.749825e-03 ];
Tc_error_271  = [ 3.026345e+00 ; 4.668335e+00 ; 4.922190e+00 ];

%-- Image #272:
omc_272 = [ NaN ; NaN ; NaN ];
Tc_272  = [ NaN ; NaN ; NaN ];
omc_error_272 = [ NaN ; NaN ; NaN ];
Tc_error_272  = [ NaN ; NaN ; NaN ];

%-- Image #273:
omc_273 = [ NaN ; NaN ; NaN ];
Tc_273  = [ NaN ; NaN ; NaN ];
omc_error_273 = [ NaN ; NaN ; NaN ];
Tc_error_273  = [ NaN ; NaN ; NaN ];

%-- Image #274:
omc_274 = [ NaN ; NaN ; NaN ];
Tc_274  = [ NaN ; NaN ; NaN ];
omc_error_274 = [ NaN ; NaN ; NaN ];
Tc_error_274  = [ NaN ; NaN ; NaN ];

%-- Image #275:
omc_275 = [ NaN ; NaN ; NaN ];
Tc_275  = [ NaN ; NaN ; NaN ];
omc_error_275 = [ NaN ; NaN ; NaN ];
Tc_error_275  = [ NaN ; NaN ; NaN ];

%-- Image #276:
omc_276 = [ 2.872112e+00 ; -7.294664e-01 ; 7.475822e-01 ];
Tc_276  = [ -5.520850e+02 ; 1.129589e+02 ; 8.886206e+02 ];
omc_error_276 = [ 2.632206e-03 ; 2.476429e-03 ; 4.484699e-03 ];
Tc_error_276  = [ 2.677530e+00 ; 4.153215e+00 ; 4.208982e+00 ];

%-- Image #277:
omc_277 = [ NaN ; NaN ; NaN ];
Tc_277  = [ NaN ; NaN ; NaN ];
omc_error_277 = [ NaN ; NaN ; NaN ];
Tc_error_277  = [ NaN ; NaN ; NaN ];

%-- Image #278:
omc_278 = [ NaN ; NaN ; NaN ];
Tc_278  = [ NaN ; NaN ; NaN ];
omc_error_278 = [ NaN ; NaN ; NaN ];
Tc_error_278  = [ NaN ; NaN ; NaN ];

%-- Image #279:
omc_279 = [ NaN ; NaN ; NaN ];
Tc_279  = [ NaN ; NaN ; NaN ];
omc_error_279 = [ NaN ; NaN ; NaN ];
Tc_error_279  = [ NaN ; NaN ; NaN ];

%-- Image #280:
omc_280 = [ NaN ; NaN ; NaN ];
Tc_280  = [ NaN ; NaN ; NaN ];
omc_error_280 = [ NaN ; NaN ; NaN ];
Tc_error_280  = [ NaN ; NaN ; NaN ];

%-- Image #281:
omc_281 = [ NaN ; NaN ; NaN ];
Tc_281  = [ NaN ; NaN ; NaN ];
omc_error_281 = [ NaN ; NaN ; NaN ];
Tc_error_281  = [ NaN ; NaN ; NaN ];

%-- Image #282:
omc_282 = [ NaN ; NaN ; NaN ];
Tc_282  = [ NaN ; NaN ; NaN ];
omc_error_282 = [ NaN ; NaN ; NaN ];
Tc_error_282  = [ NaN ; NaN ; NaN ];

%-- Image #283:
omc_283 = [ NaN ; NaN ; NaN ];
Tc_283  = [ NaN ; NaN ; NaN ];
omc_error_283 = [ NaN ; NaN ; NaN ];
Tc_error_283  = [ NaN ; NaN ; NaN ];

%-- Image #284:
omc_284 = [ NaN ; NaN ; NaN ];
Tc_284  = [ NaN ; NaN ; NaN ];
omc_error_284 = [ NaN ; NaN ; NaN ];
Tc_error_284  = [ NaN ; NaN ; NaN ];

%-- Image #285:
omc_285 = [ NaN ; NaN ; NaN ];
Tc_285  = [ NaN ; NaN ; NaN ];
omc_error_285 = [ NaN ; NaN ; NaN ];
Tc_error_285  = [ NaN ; NaN ; NaN ];

%-- Image #286:
omc_286 = [ NaN ; NaN ; NaN ];
Tc_286  = [ NaN ; NaN ; NaN ];
omc_error_286 = [ NaN ; NaN ; NaN ];
Tc_error_286  = [ NaN ; NaN ; NaN ];

%-- Image #287:
omc_287 = [ NaN ; NaN ; NaN ];
Tc_287  = [ NaN ; NaN ; NaN ];
omc_error_287 = [ NaN ; NaN ; NaN ];
Tc_error_287  = [ NaN ; NaN ; NaN ];

%-- Image #288:
omc_288 = [ NaN ; NaN ; NaN ];
Tc_288  = [ NaN ; NaN ; NaN ];
omc_error_288 = [ NaN ; NaN ; NaN ];
Tc_error_288  = [ NaN ; NaN ; NaN ];

%-- Image #289:
omc_289 = [ NaN ; NaN ; NaN ];
Tc_289  = [ NaN ; NaN ; NaN ];
omc_error_289 = [ NaN ; NaN ; NaN ];
Tc_error_289  = [ NaN ; NaN ; NaN ];

%-- Image #290:
omc_290 = [ NaN ; NaN ; NaN ];
Tc_290  = [ NaN ; NaN ; NaN ];
omc_error_290 = [ NaN ; NaN ; NaN ];
Tc_error_290  = [ NaN ; NaN ; NaN ];

%-- Image #291:
omc_291 = [ NaN ; NaN ; NaN ];
Tc_291  = [ NaN ; NaN ; NaN ];
omc_error_291 = [ NaN ; NaN ; NaN ];
Tc_error_291  = [ NaN ; NaN ; NaN ];

%-- Image #292:
omc_292 = [ NaN ; NaN ; NaN ];
Tc_292  = [ NaN ; NaN ; NaN ];
omc_error_292 = [ NaN ; NaN ; NaN ];
Tc_error_292  = [ NaN ; NaN ; NaN ];

%-- Image #293:
omc_293 = [ NaN ; NaN ; NaN ];
Tc_293  = [ NaN ; NaN ; NaN ];
omc_error_293 = [ NaN ; NaN ; NaN ];
Tc_error_293  = [ NaN ; NaN ; NaN ];

%-- Image #294:
omc_294 = [ NaN ; NaN ; NaN ];
Tc_294  = [ NaN ; NaN ; NaN ];
omc_error_294 = [ NaN ; NaN ; NaN ];
Tc_error_294  = [ NaN ; NaN ; NaN ];

%-- Image #295:
omc_295 = [ NaN ; NaN ; NaN ];
Tc_295  = [ NaN ; NaN ; NaN ];
omc_error_295 = [ NaN ; NaN ; NaN ];
Tc_error_295  = [ NaN ; NaN ; NaN ];

%-- Image #296:
omc_296 = [ NaN ; NaN ; NaN ];
Tc_296  = [ NaN ; NaN ; NaN ];
omc_error_296 = [ NaN ; NaN ; NaN ];
Tc_error_296  = [ NaN ; NaN ; NaN ];

%-- Image #297:
omc_297 = [ NaN ; NaN ; NaN ];
Tc_297  = [ NaN ; NaN ; NaN ];
omc_error_297 = [ NaN ; NaN ; NaN ];
Tc_error_297  = [ NaN ; NaN ; NaN ];

%-- Image #298:
omc_298 = [ NaN ; NaN ; NaN ];
Tc_298  = [ NaN ; NaN ; NaN ];
omc_error_298 = [ NaN ; NaN ; NaN ];
Tc_error_298  = [ NaN ; NaN ; NaN ];

%-- Image #299:
omc_299 = [ NaN ; NaN ; NaN ];
Tc_299  = [ NaN ; NaN ; NaN ];
omc_error_299 = [ NaN ; NaN ; NaN ];
Tc_error_299  = [ NaN ; NaN ; NaN ];

%-- Image #300:
omc_300 = [ NaN ; NaN ; NaN ];
Tc_300  = [ NaN ; NaN ; NaN ];
omc_error_300 = [ NaN ; NaN ; NaN ];
Tc_error_300  = [ NaN ; NaN ; NaN ];

%-- Image #301:
omc_301 = [ NaN ; NaN ; NaN ];
Tc_301  = [ NaN ; NaN ; NaN ];
omc_error_301 = [ NaN ; NaN ; NaN ];
Tc_error_301  = [ NaN ; NaN ; NaN ];

%-- Image #302:
omc_302 = [ NaN ; NaN ; NaN ];
Tc_302  = [ NaN ; NaN ; NaN ];
omc_error_302 = [ NaN ; NaN ; NaN ];
Tc_error_302  = [ NaN ; NaN ; NaN ];

%-- Image #303:
omc_303 = [ NaN ; NaN ; NaN ];
Tc_303  = [ NaN ; NaN ; NaN ];
omc_error_303 = [ NaN ; NaN ; NaN ];
Tc_error_303  = [ NaN ; NaN ; NaN ];

%-- Image #304:
omc_304 = [ NaN ; NaN ; NaN ];
Tc_304  = [ NaN ; NaN ; NaN ];
omc_error_304 = [ NaN ; NaN ; NaN ];
Tc_error_304  = [ NaN ; NaN ; NaN ];

%-- Image #305:
omc_305 = [ NaN ; NaN ; NaN ];
Tc_305  = [ NaN ; NaN ; NaN ];
omc_error_305 = [ NaN ; NaN ; NaN ];
Tc_error_305  = [ NaN ; NaN ; NaN ];

%-- Image #306:
omc_306 = [ NaN ; NaN ; NaN ];
Tc_306  = [ NaN ; NaN ; NaN ];
omc_error_306 = [ NaN ; NaN ; NaN ];
Tc_error_306  = [ NaN ; NaN ; NaN ];

%-- Image #307:
omc_307 = [ NaN ; NaN ; NaN ];
Tc_307  = [ NaN ; NaN ; NaN ];
omc_error_307 = [ NaN ; NaN ; NaN ];
Tc_error_307  = [ NaN ; NaN ; NaN ];

%-- Image #308:
omc_308 = [ NaN ; NaN ; NaN ];
Tc_308  = [ NaN ; NaN ; NaN ];
omc_error_308 = [ NaN ; NaN ; NaN ];
Tc_error_308  = [ NaN ; NaN ; NaN ];

%-- Image #309:
omc_309 = [ NaN ; NaN ; NaN ];
Tc_309  = [ NaN ; NaN ; NaN ];
omc_error_309 = [ NaN ; NaN ; NaN ];
Tc_error_309  = [ NaN ; NaN ; NaN ];

%-- Image #310:
omc_310 = [ NaN ; NaN ; NaN ];
Tc_310  = [ NaN ; NaN ; NaN ];
omc_error_310 = [ NaN ; NaN ; NaN ];
Tc_error_310  = [ NaN ; NaN ; NaN ];

%-- Image #311:
omc_311 = [ NaN ; NaN ; NaN ];
Tc_311  = [ NaN ; NaN ; NaN ];
omc_error_311 = [ NaN ; NaN ; NaN ];
Tc_error_311  = [ NaN ; NaN ; NaN ];

%-- Image #312:
omc_312 = [ NaN ; NaN ; NaN ];
Tc_312  = [ NaN ; NaN ; NaN ];
omc_error_312 = [ NaN ; NaN ; NaN ];
Tc_error_312  = [ NaN ; NaN ; NaN ];

%-- Image #313:
omc_313 = [ NaN ; NaN ; NaN ];
Tc_313  = [ NaN ; NaN ; NaN ];
omc_error_313 = [ NaN ; NaN ; NaN ];
Tc_error_313  = [ NaN ; NaN ; NaN ];

%-- Image #314:
omc_314 = [ NaN ; NaN ; NaN ];
Tc_314  = [ NaN ; NaN ; NaN ];
omc_error_314 = [ NaN ; NaN ; NaN ];
Tc_error_314  = [ NaN ; NaN ; NaN ];

%-- Image #315:
omc_315 = [ NaN ; NaN ; NaN ];
Tc_315  = [ NaN ; NaN ; NaN ];
omc_error_315 = [ NaN ; NaN ; NaN ];
Tc_error_315  = [ NaN ; NaN ; NaN ];

%-- Image #316:
omc_316 = [ NaN ; NaN ; NaN ];
Tc_316  = [ NaN ; NaN ; NaN ];
omc_error_316 = [ NaN ; NaN ; NaN ];
Tc_error_316  = [ NaN ; NaN ; NaN ];

%-- Image #317:
omc_317 = [ NaN ; NaN ; NaN ];
Tc_317  = [ NaN ; NaN ; NaN ];
omc_error_317 = [ NaN ; NaN ; NaN ];
Tc_error_317  = [ NaN ; NaN ; NaN ];

%-- Image #318:
omc_318 = [ NaN ; NaN ; NaN ];
Tc_318  = [ NaN ; NaN ; NaN ];
omc_error_318 = [ NaN ; NaN ; NaN ];
Tc_error_318  = [ NaN ; NaN ; NaN ];

%-- Image #319:
omc_319 = [ NaN ; NaN ; NaN ];
Tc_319  = [ NaN ; NaN ; NaN ];
omc_error_319 = [ NaN ; NaN ; NaN ];
Tc_error_319  = [ NaN ; NaN ; NaN ];

%-- Image #320:
omc_320 = [ NaN ; NaN ; NaN ];
Tc_320  = [ NaN ; NaN ; NaN ];
omc_error_320 = [ NaN ; NaN ; NaN ];
Tc_error_320  = [ NaN ; NaN ; NaN ];

%-- Image #321:
omc_321 = [ NaN ; NaN ; NaN ];
Tc_321  = [ NaN ; NaN ; NaN ];
omc_error_321 = [ NaN ; NaN ; NaN ];
Tc_error_321  = [ NaN ; NaN ; NaN ];

%-- Image #322:
omc_322 = [ NaN ; NaN ; NaN ];
Tc_322  = [ NaN ; NaN ; NaN ];
omc_error_322 = [ NaN ; NaN ; NaN ];
Tc_error_322  = [ NaN ; NaN ; NaN ];

%-- Image #323:
omc_323 = [ NaN ; NaN ; NaN ];
Tc_323  = [ NaN ; NaN ; NaN ];
omc_error_323 = [ NaN ; NaN ; NaN ];
Tc_error_323  = [ NaN ; NaN ; NaN ];

%-- Image #324:
omc_324 = [ NaN ; NaN ; NaN ];
Tc_324  = [ NaN ; NaN ; NaN ];
omc_error_324 = [ NaN ; NaN ; NaN ];
Tc_error_324  = [ NaN ; NaN ; NaN ];

%-- Image #325:
omc_325 = [ NaN ; NaN ; NaN ];
Tc_325  = [ NaN ; NaN ; NaN ];
omc_error_325 = [ NaN ; NaN ; NaN ];
Tc_error_325  = [ NaN ; NaN ; NaN ];

%-- Image #326:
omc_326 = [ NaN ; NaN ; NaN ];
Tc_326  = [ NaN ; NaN ; NaN ];
omc_error_326 = [ NaN ; NaN ; NaN ];
Tc_error_326  = [ NaN ; NaN ; NaN ];

%-- Image #327:
omc_327 = [ NaN ; NaN ; NaN ];
Tc_327  = [ NaN ; NaN ; NaN ];
omc_error_327 = [ NaN ; NaN ; NaN ];
Tc_error_327  = [ NaN ; NaN ; NaN ];

%-- Image #328:
omc_328 = [ NaN ; NaN ; NaN ];
Tc_328  = [ NaN ; NaN ; NaN ];
omc_error_328 = [ NaN ; NaN ; NaN ];
Tc_error_328  = [ NaN ; NaN ; NaN ];

%-- Image #329:
omc_329 = [ NaN ; NaN ; NaN ];
Tc_329  = [ NaN ; NaN ; NaN ];
omc_error_329 = [ NaN ; NaN ; NaN ];
Tc_error_329  = [ NaN ; NaN ; NaN ];

%-- Image #330:
omc_330 = [ NaN ; NaN ; NaN ];
Tc_330  = [ NaN ; NaN ; NaN ];
omc_error_330 = [ NaN ; NaN ; NaN ];
Tc_error_330  = [ NaN ; NaN ; NaN ];

%-- Image #331:
omc_331 = [ NaN ; NaN ; NaN ];
Tc_331  = [ NaN ; NaN ; NaN ];
omc_error_331 = [ NaN ; NaN ; NaN ];
Tc_error_331  = [ NaN ; NaN ; NaN ];

%-- Image #332:
omc_332 = [ NaN ; NaN ; NaN ];
Tc_332  = [ NaN ; NaN ; NaN ];
omc_error_332 = [ NaN ; NaN ; NaN ];
Tc_error_332  = [ NaN ; NaN ; NaN ];

%-- Image #333:
omc_333 = [ NaN ; NaN ; NaN ];
Tc_333  = [ NaN ; NaN ; NaN ];
omc_error_333 = [ NaN ; NaN ; NaN ];
Tc_error_333  = [ NaN ; NaN ; NaN ];

%-- Image #334:
omc_334 = [ NaN ; NaN ; NaN ];
Tc_334  = [ NaN ; NaN ; NaN ];
omc_error_334 = [ NaN ; NaN ; NaN ];
Tc_error_334  = [ NaN ; NaN ; NaN ];

%-- Image #335:
omc_335 = [ 2.808636e+00 ; -5.719869e-01 ; 1.130473e-01 ];
Tc_335  = [ -1.183443e+02 ; 1.412605e+02 ; 9.529825e+02 ];
omc_error_335 = [ 2.483900e-03 ; 1.756021e-03 ; 2.924976e-03 ];
Tc_error_335  = [ 2.560081e+00 ; 4.281248e+00 ; 4.704668e+00 ];

%-- Image #336:
omc_336 = [ NaN ; NaN ; NaN ];
Tc_336  = [ NaN ; NaN ; NaN ];
omc_error_336 = [ NaN ; NaN ; NaN ];
Tc_error_336  = [ NaN ; NaN ; NaN ];

%-- Image #337:
omc_337 = [ NaN ; NaN ; NaN ];
Tc_337  = [ NaN ; NaN ; NaN ];
omc_error_337 = [ NaN ; NaN ; NaN ];
Tc_error_337  = [ NaN ; NaN ; NaN ];

%-- Image #338:
omc_338 = [ 2.618802e+00 ; -6.172530e-01 ; 2.211684e-01 ];
Tc_338  = [ -1.733510e+02 ; 3.999050e+02 ; 9.310953e+02 ];
omc_error_338 = [ 3.188672e-03 ; 1.709445e-03 ; 3.215940e-03 ];
Tc_error_338  = [ 2.815538e+00 ; 4.591200e+00 ; 4.799343e+00 ];

%-- Image #339:
omc_339 = [ NaN ; NaN ; NaN ];
Tc_339  = [ NaN ; NaN ; NaN ];
omc_error_339 = [ NaN ; NaN ; NaN ];
Tc_error_339  = [ NaN ; NaN ; NaN ];

%-- Image #340:
omc_340 = [ NaN ; NaN ; NaN ];
Tc_340  = [ NaN ; NaN ; NaN ];
omc_error_340 = [ NaN ; NaN ; NaN ];
Tc_error_340  = [ NaN ; NaN ; NaN ];

%-- Image #341:
omc_341 = [ NaN ; NaN ; NaN ];
Tc_341  = [ NaN ; NaN ; NaN ];
omc_error_341 = [ NaN ; NaN ; NaN ];
Tc_error_341  = [ NaN ; NaN ; NaN ];

%-- Image #342:
omc_342 = [ 2.494629e+00 ; -3.224257e-01 ; 1.773498e-01 ];
Tc_342  = [ -8.876468e+01 ; 6.452152e+02 ; 8.789105e+02 ];
omc_error_342 = [ 3.804620e-03 ; 1.563178e-03 ; 3.323576e-03 ];
Tc_error_342  = [ 2.972996e+00 ; 4.733430e+00 ; 4.645489e+00 ];

%-- Image #343:
omc_343 = [ NaN ; NaN ; NaN ];
Tc_343  = [ NaN ; NaN ; NaN ];
omc_error_343 = [ NaN ; NaN ; NaN ];
Tc_error_343  = [ NaN ; NaN ; NaN ];

%-- Image #344:
omc_344 = [ NaN ; NaN ; NaN ];
Tc_344  = [ NaN ; NaN ; NaN ];
omc_error_344 = [ NaN ; NaN ; NaN ];
Tc_error_344  = [ NaN ; NaN ; NaN ];

%-- Image #345:
omc_345 = [ NaN ; NaN ; NaN ];
Tc_345  = [ NaN ; NaN ; NaN ];
omc_error_345 = [ NaN ; NaN ; NaN ];
Tc_error_345  = [ NaN ; NaN ; NaN ];

%-- Image #346:
omc_346 = [ NaN ; NaN ; NaN ];
Tc_346  = [ NaN ; NaN ; NaN ];
omc_error_346 = [ NaN ; NaN ; NaN ];
Tc_error_346  = [ NaN ; NaN ; NaN ];

%-- Image #347:
omc_347 = [ 2.506128e+00 ; -4.941373e-02 ; 3.373991e-02 ];
Tc_347  = [ 4.342457e+01 ; 6.711856e+02 ; 8.727103e+02 ];
omc_error_347 = [ 3.835260e-03 ; 1.452119e-03 ; 3.078418e-03 ];
Tc_error_347  = [ 3.002696e+00 ; 4.631787e+00 ; 4.364828e+00 ];

%-- Image #348:
omc_348 = [ NaN ; NaN ; NaN ];
Tc_348  = [ NaN ; NaN ; NaN ];
omc_error_348 = [ NaN ; NaN ; NaN ];
Tc_error_348  = [ NaN ; NaN ; NaN ];

%-- Image #349:
omc_349 = [ NaN ; NaN ; NaN ];
Tc_349  = [ NaN ; NaN ; NaN ];
omc_error_349 = [ NaN ; NaN ; NaN ];
Tc_error_349  = [ NaN ; NaN ; NaN ];

%-- Image #350:
omc_350 = [ NaN ; NaN ; NaN ];
Tc_350  = [ NaN ; NaN ; NaN ];
omc_error_350 = [ NaN ; NaN ; NaN ];
Tc_error_350  = [ NaN ; NaN ; NaN ];

%-- Image #351:
omc_351 = [ NaN ; NaN ; NaN ];
Tc_351  = [ NaN ; NaN ; NaN ];
omc_error_351 = [ NaN ; NaN ; NaN ];
Tc_error_351  = [ NaN ; NaN ; NaN ];

%-- Image #352:
omc_352 = [ 2.504984e+00 ; 1.045211e-01 ; -2.048114e-02 ];
Tc_352  = [ 1.047552e+02 ; 6.905177e+02 ; 8.599189e+02 ];
omc_error_352 = [ 3.882276e-03 ; 1.435618e-03 ; 2.995299e-03 ];
Tc_error_352  = [ 3.047404e+00 ; 4.521973e+00 ; 4.222640e+00 ];

%-- Image #353:
omc_353 = [ NaN ; NaN ; NaN ];
Tc_353  = [ NaN ; NaN ; NaN ];
omc_error_353 = [ NaN ; NaN ; NaN ];
Tc_error_353  = [ NaN ; NaN ; NaN ];

%-- Image #354:
omc_354 = [ NaN ; NaN ; NaN ];
Tc_354  = [ NaN ; NaN ; NaN ];
omc_error_354 = [ NaN ; NaN ; NaN ];
Tc_error_354  = [ NaN ; NaN ; NaN ];

%-- Image #355:
omc_355 = [ NaN ; NaN ; NaN ];
Tc_355  = [ NaN ; NaN ; NaN ];
omc_error_355 = [ NaN ; NaN ; NaN ];
Tc_error_355  = [ NaN ; NaN ; NaN ];

%-- Image #356:
omc_356 = [ NaN ; NaN ; NaN ];
Tc_356  = [ NaN ; NaN ; NaN ];
omc_error_356 = [ NaN ; NaN ; NaN ];
Tc_error_356  = [ NaN ; NaN ; NaN ];

%-- Image #357:
omc_357 = [ NaN ; NaN ; NaN ];
Tc_357  = [ NaN ; NaN ; NaN ];
omc_error_357 = [ NaN ; NaN ; NaN ];
Tc_error_357  = [ NaN ; NaN ; NaN ];

%-- Image #358:
omc_358 = [ NaN ; NaN ; NaN ];
Tc_358  = [ NaN ; NaN ; NaN ];
omc_error_358 = [ NaN ; NaN ; NaN ];
Tc_error_358  = [ NaN ; NaN ; NaN ];

%-- Image #359:
omc_359 = [ NaN ; NaN ; NaN ];
Tc_359  = [ NaN ; NaN ; NaN ];
omc_error_359 = [ NaN ; NaN ; NaN ];
Tc_error_359  = [ NaN ; NaN ; NaN ];

%-- Image #360:
omc_360 = [ NaN ; NaN ; NaN ];
Tc_360  = [ NaN ; NaN ; NaN ];
omc_error_360 = [ NaN ; NaN ; NaN ];
Tc_error_360  = [ NaN ; NaN ; NaN ];

%-- Image #361:
omc_361 = [ NaN ; NaN ; NaN ];
Tc_361  = [ NaN ; NaN ; NaN ];
omc_error_361 = [ NaN ; NaN ; NaN ];
Tc_error_361  = [ NaN ; NaN ; NaN ];

%-- Image #362:
omc_362 = [ NaN ; NaN ; NaN ];
Tc_362  = [ NaN ; NaN ; NaN ];
omc_error_362 = [ NaN ; NaN ; NaN ];
Tc_error_362  = [ NaN ; NaN ; NaN ];

%-- Image #363:
omc_363 = [ NaN ; NaN ; NaN ];
Tc_363  = [ NaN ; NaN ; NaN ];
omc_error_363 = [ NaN ; NaN ; NaN ];
Tc_error_363  = [ NaN ; NaN ; NaN ];

%-- Image #364:
omc_364 = [ NaN ; NaN ; NaN ];
Tc_364  = [ NaN ; NaN ; NaN ];
omc_error_364 = [ NaN ; NaN ; NaN ];
Tc_error_364  = [ NaN ; NaN ; NaN ];

%-- Image #365:
omc_365 = [ NaN ; NaN ; NaN ];
Tc_365  = [ NaN ; NaN ; NaN ];
omc_error_365 = [ NaN ; NaN ; NaN ];
Tc_error_365  = [ NaN ; NaN ; NaN ];

%-- Image #366:
omc_366 = [ NaN ; NaN ; NaN ];
Tc_366  = [ NaN ; NaN ; NaN ];
omc_error_366 = [ NaN ; NaN ; NaN ];
Tc_error_366  = [ NaN ; NaN ; NaN ];

%-- Image #367:
omc_367 = [ NaN ; NaN ; NaN ];
Tc_367  = [ NaN ; NaN ; NaN ];
omc_error_367 = [ NaN ; NaN ; NaN ];
Tc_error_367  = [ NaN ; NaN ; NaN ];

%-- Image #368:
omc_368 = [ NaN ; NaN ; NaN ];
Tc_368  = [ NaN ; NaN ; NaN ];
omc_error_368 = [ NaN ; NaN ; NaN ];
Tc_error_368  = [ NaN ; NaN ; NaN ];

%-- Image #369:
omc_369 = [ NaN ; NaN ; NaN ];
Tc_369  = [ NaN ; NaN ; NaN ];
omc_error_369 = [ NaN ; NaN ; NaN ];
Tc_error_369  = [ NaN ; NaN ; NaN ];

%-- Image #370:
omc_370 = [ NaN ; NaN ; NaN ];
Tc_370  = [ NaN ; NaN ; NaN ];
omc_error_370 = [ NaN ; NaN ; NaN ];
Tc_error_370  = [ NaN ; NaN ; NaN ];

%-- Image #371:
omc_371 = [ NaN ; NaN ; NaN ];
Tc_371  = [ NaN ; NaN ; NaN ];
omc_error_371 = [ NaN ; NaN ; NaN ];
Tc_error_371  = [ NaN ; NaN ; NaN ];

%-- Image #372:
omc_372 = [ NaN ; NaN ; NaN ];
Tc_372  = [ NaN ; NaN ; NaN ];
omc_error_372 = [ NaN ; NaN ; NaN ];
Tc_error_372  = [ NaN ; NaN ; NaN ];

%-- Image #373:
omc_373 = [ NaN ; NaN ; NaN ];
Tc_373  = [ NaN ; NaN ; NaN ];
omc_error_373 = [ NaN ; NaN ; NaN ];
Tc_error_373  = [ NaN ; NaN ; NaN ];

%-- Image #374:
omc_374 = [ NaN ; NaN ; NaN ];
Tc_374  = [ NaN ; NaN ; NaN ];
omc_error_374 = [ NaN ; NaN ; NaN ];
Tc_error_374  = [ NaN ; NaN ; NaN ];

%-- Image #375:
omc_375 = [ NaN ; NaN ; NaN ];
Tc_375  = [ NaN ; NaN ; NaN ];
omc_error_375 = [ NaN ; NaN ; NaN ];
Tc_error_375  = [ NaN ; NaN ; NaN ];

%-- Image #376:
omc_376 = [ NaN ; NaN ; NaN ];
Tc_376  = [ NaN ; NaN ; NaN ];
omc_error_376 = [ NaN ; NaN ; NaN ];
Tc_error_376  = [ NaN ; NaN ; NaN ];

%-- Image #377:
omc_377 = [ NaN ; NaN ; NaN ];
Tc_377  = [ NaN ; NaN ; NaN ];
omc_error_377 = [ NaN ; NaN ; NaN ];
Tc_error_377  = [ NaN ; NaN ; NaN ];

%-- Image #378:
omc_378 = [ NaN ; NaN ; NaN ];
Tc_378  = [ NaN ; NaN ; NaN ];
omc_error_378 = [ NaN ; NaN ; NaN ];
Tc_error_378  = [ NaN ; NaN ; NaN ];

%-- Image #379:
omc_379 = [ NaN ; NaN ; NaN ];
Tc_379  = [ NaN ; NaN ; NaN ];
omc_error_379 = [ NaN ; NaN ; NaN ];
Tc_error_379  = [ NaN ; NaN ; NaN ];

%-- Image #380:
omc_380 = [ NaN ; NaN ; NaN ];
Tc_380  = [ NaN ; NaN ; NaN ];
omc_error_380 = [ NaN ; NaN ; NaN ];
Tc_error_380  = [ NaN ; NaN ; NaN ];

%-- Image #381:
omc_381 = [ NaN ; NaN ; NaN ];
Tc_381  = [ NaN ; NaN ; NaN ];
omc_error_381 = [ NaN ; NaN ; NaN ];
Tc_error_381  = [ NaN ; NaN ; NaN ];

%-- Image #382:
omc_382 = [ NaN ; NaN ; NaN ];
Tc_382  = [ NaN ; NaN ; NaN ];
omc_error_382 = [ NaN ; NaN ; NaN ];
Tc_error_382  = [ NaN ; NaN ; NaN ];

%-- Image #383:
omc_383 = [ NaN ; NaN ; NaN ];
Tc_383  = [ NaN ; NaN ; NaN ];
omc_error_383 = [ NaN ; NaN ; NaN ];
Tc_error_383  = [ NaN ; NaN ; NaN ];

%-- Image #384:
omc_384 = [ NaN ; NaN ; NaN ];
Tc_384  = [ NaN ; NaN ; NaN ];
omc_error_384 = [ NaN ; NaN ; NaN ];
Tc_error_384  = [ NaN ; NaN ; NaN ];

%-- Image #385:
omc_385 = [ NaN ; NaN ; NaN ];
Tc_385  = [ NaN ; NaN ; NaN ];
omc_error_385 = [ NaN ; NaN ; NaN ];
Tc_error_385  = [ NaN ; NaN ; NaN ];

%-- Image #386:
omc_386 = [ NaN ; NaN ; NaN ];
Tc_386  = [ NaN ; NaN ; NaN ];
omc_error_386 = [ NaN ; NaN ; NaN ];
Tc_error_386  = [ NaN ; NaN ; NaN ];

%-- Image #387:
omc_387 = [ NaN ; NaN ; NaN ];
Tc_387  = [ NaN ; NaN ; NaN ];
omc_error_387 = [ NaN ; NaN ; NaN ];
Tc_error_387  = [ NaN ; NaN ; NaN ];

%-- Image #388:
omc_388 = [ 2.454437e+00 ; -8.190025e-02 ; 1.296482e-01 ];
Tc_388  = [ -3.609417e+00 ; 7.728158e+02 ; 8.468651e+02 ];
omc_error_388 = [ 4.006747e-03 ; 1.518372e-03 ; 3.158865e-03 ];
Tc_error_388  = [ 3.082931e+00 ; 4.693654e+00 ; 4.415731e+00 ];

%-- Image #389:
omc_389 = [ NaN ; NaN ; NaN ];
Tc_389  = [ NaN ; NaN ; NaN ];
omc_error_389 = [ NaN ; NaN ; NaN ];
Tc_error_389  = [ NaN ; NaN ; NaN ];

%-- Image #390:
omc_390 = [ NaN ; NaN ; NaN ];
Tc_390  = [ NaN ; NaN ; NaN ];
omc_error_390 = [ NaN ; NaN ; NaN ];
Tc_error_390  = [ NaN ; NaN ; NaN ];

%-- Image #391:
omc_391 = [ NaN ; NaN ; NaN ];
Tc_391  = [ NaN ; NaN ; NaN ];
omc_error_391 = [ NaN ; NaN ; NaN ];
Tc_error_391  = [ NaN ; NaN ; NaN ];

%-- Image #392:
omc_392 = [ NaN ; NaN ; NaN ];
Tc_392  = [ NaN ; NaN ; NaN ];
omc_error_392 = [ NaN ; NaN ; NaN ];
Tc_error_392  = [ NaN ; NaN ; NaN ];

%-- Image #393:
omc_393 = [ NaN ; NaN ; NaN ];
Tc_393  = [ NaN ; NaN ; NaN ];
omc_error_393 = [ NaN ; NaN ; NaN ];
Tc_error_393  = [ NaN ; NaN ; NaN ];

%-- Image #394:
omc_394 = [ NaN ; NaN ; NaN ];
Tc_394  = [ NaN ; NaN ; NaN ];
omc_error_394 = [ NaN ; NaN ; NaN ];
Tc_error_394  = [ NaN ; NaN ; NaN ];

%-- Image #395:
omc_395 = [ NaN ; NaN ; NaN ];
Tc_395  = [ NaN ; NaN ; NaN ];
omc_error_395 = [ NaN ; NaN ; NaN ];
Tc_error_395  = [ NaN ; NaN ; NaN ];

%-- Image #396:
omc_396 = [ NaN ; NaN ; NaN ];
Tc_396  = [ NaN ; NaN ; NaN ];
omc_error_396 = [ NaN ; NaN ; NaN ];
Tc_error_396  = [ NaN ; NaN ; NaN ];

%-- Image #397:
omc_397 = [ NaN ; NaN ; NaN ];
Tc_397  = [ NaN ; NaN ; NaN ];
omc_error_397 = [ NaN ; NaN ; NaN ];
Tc_error_397  = [ NaN ; NaN ; NaN ];

%-- Image #398:
omc_398 = [ NaN ; NaN ; NaN ];
Tc_398  = [ NaN ; NaN ; NaN ];
omc_error_398 = [ NaN ; NaN ; NaN ];
Tc_error_398  = [ NaN ; NaN ; NaN ];

%-- Image #399:
omc_399 = [ NaN ; NaN ; NaN ];
Tc_399  = [ NaN ; NaN ; NaN ];
omc_error_399 = [ NaN ; NaN ; NaN ];
Tc_error_399  = [ NaN ; NaN ; NaN ];

%-- Image #400:
omc_400 = [ NaN ; NaN ; NaN ];
Tc_400  = [ NaN ; NaN ; NaN ];
omc_error_400 = [ NaN ; NaN ; NaN ];
Tc_error_400  = [ NaN ; NaN ; NaN ];

%-- Image #401:
omc_401 = [ NaN ; NaN ; NaN ];
Tc_401  = [ NaN ; NaN ; NaN ];
omc_error_401 = [ NaN ; NaN ; NaN ];
Tc_error_401  = [ NaN ; NaN ; NaN ];

%-- Image #402:
omc_402 = [ NaN ; NaN ; NaN ];
Tc_402  = [ NaN ; NaN ; NaN ];
omc_error_402 = [ NaN ; NaN ; NaN ];
Tc_error_402  = [ NaN ; NaN ; NaN ];

%-- Image #403:
omc_403 = [ NaN ; NaN ; NaN ];
Tc_403  = [ NaN ; NaN ; NaN ];
omc_error_403 = [ NaN ; NaN ; NaN ];
Tc_error_403  = [ NaN ; NaN ; NaN ];

%-- Image #404:
omc_404 = [ NaN ; NaN ; NaN ];
Tc_404  = [ NaN ; NaN ; NaN ];
omc_error_404 = [ NaN ; NaN ; NaN ];
Tc_error_404  = [ NaN ; NaN ; NaN ];

%-- Image #405:
omc_405 = [ NaN ; NaN ; NaN ];
Tc_405  = [ NaN ; NaN ; NaN ];
omc_error_405 = [ NaN ; NaN ; NaN ];
Tc_error_405  = [ NaN ; NaN ; NaN ];

%-- Image #406:
omc_406 = [ NaN ; NaN ; NaN ];
Tc_406  = [ NaN ; NaN ; NaN ];
omc_error_406 = [ NaN ; NaN ; NaN ];
Tc_error_406  = [ NaN ; NaN ; NaN ];

%-- Image #407:
omc_407 = [ NaN ; NaN ; NaN ];
Tc_407  = [ NaN ; NaN ; NaN ];
omc_error_407 = [ NaN ; NaN ; NaN ];
Tc_error_407  = [ NaN ; NaN ; NaN ];

%-- Image #408:
omc_408 = [ NaN ; NaN ; NaN ];
Tc_408  = [ NaN ; NaN ; NaN ];
omc_error_408 = [ NaN ; NaN ; NaN ];
Tc_error_408  = [ NaN ; NaN ; NaN ];

%-- Image #409:
omc_409 = [ NaN ; NaN ; NaN ];
Tc_409  = [ NaN ; NaN ; NaN ];
omc_error_409 = [ NaN ; NaN ; NaN ];
Tc_error_409  = [ NaN ; NaN ; NaN ];

%-- Image #410:
omc_410 = [ NaN ; NaN ; NaN ];
Tc_410  = [ NaN ; NaN ; NaN ];
omc_error_410 = [ NaN ; NaN ; NaN ];
Tc_error_410  = [ NaN ; NaN ; NaN ];

%-- Image #411:
omc_411 = [ NaN ; NaN ; NaN ];
Tc_411  = [ NaN ; NaN ; NaN ];
omc_error_411 = [ NaN ; NaN ; NaN ];
Tc_error_411  = [ NaN ; NaN ; NaN ];

%-- Image #412:
omc_412 = [ NaN ; NaN ; NaN ];
Tc_412  = [ NaN ; NaN ; NaN ];
omc_error_412 = [ NaN ; NaN ; NaN ];
Tc_error_412  = [ NaN ; NaN ; NaN ];

%-- Image #413:
omc_413 = [ NaN ; NaN ; NaN ];
Tc_413  = [ NaN ; NaN ; NaN ];
omc_error_413 = [ NaN ; NaN ; NaN ];
Tc_error_413  = [ NaN ; NaN ; NaN ];

%-- Image #414:
omc_414 = [ NaN ; NaN ; NaN ];
Tc_414  = [ NaN ; NaN ; NaN ];
omc_error_414 = [ NaN ; NaN ; NaN ];
Tc_error_414  = [ NaN ; NaN ; NaN ];

%-- Image #415:
omc_415 = [ NaN ; NaN ; NaN ];
Tc_415  = [ NaN ; NaN ; NaN ];
omc_error_415 = [ NaN ; NaN ; NaN ];
Tc_error_415  = [ NaN ; NaN ; NaN ];

%-- Image #416:
omc_416 = [ NaN ; NaN ; NaN ];
Tc_416  = [ NaN ; NaN ; NaN ];
omc_error_416 = [ NaN ; NaN ; NaN ];
Tc_error_416  = [ NaN ; NaN ; NaN ];

%-- Image #417:
omc_417 = [ 2.919385e+00 ; -6.021384e-01 ; 2.770708e-01 ];
Tc_417  = [ 4.759336e+01 ; 3.086359e+02 ; 9.685301e+02 ];
omc_error_417 = [ 2.168519e-03 ; 1.905482e-03 ; 3.174410e-03 ];
Tc_error_417  = [ 2.631492e+00 ; 4.475490e+00 ; 4.673265e+00 ];

%-- Image #418:
omc_418 = [ NaN ; NaN ; NaN ];
Tc_418  = [ NaN ; NaN ; NaN ];
omc_error_418 = [ NaN ; NaN ; NaN ];
Tc_error_418  = [ NaN ; NaN ; NaN ];

%-- Image #419:
omc_419 = [ NaN ; NaN ; NaN ];
Tc_419  = [ NaN ; NaN ; NaN ];
omc_error_419 = [ NaN ; NaN ; NaN ];
Tc_error_419  = [ NaN ; NaN ; NaN ];

%-- Image #420:
omc_420 = [ 3.078988e+00 ; -4.657747e-01 ; 2.775510e-01 ];
Tc_420  = [ 4.906170e+01 ; 2.008264e+02 ; 9.733943e+02 ];
omc_error_420 = [ 2.029774e-03 ; 1.944712e-03 ; 3.257917e-03 ];
Tc_error_420  = [ 2.465644e+00 ; 4.301216e+00 ; 4.423854e+00 ];

%-- Image #421:
omc_421 = [ NaN ; NaN ; NaN ];
Tc_421  = [ NaN ; NaN ; NaN ];
omc_error_421 = [ NaN ; NaN ; NaN ];
Tc_error_421  = [ NaN ; NaN ; NaN ];

%-- Image #422:
omc_422 = [ NaN ; NaN ; NaN ];
Tc_422  = [ NaN ; NaN ; NaN ];
omc_error_422 = [ NaN ; NaN ; NaN ];
Tc_error_422  = [ NaN ; NaN ; NaN ];

%-- Image #423:
omc_423 = [ NaN ; NaN ; NaN ];
Tc_423  = [ NaN ; NaN ; NaN ];
omc_error_423 = [ NaN ; NaN ; NaN ];
Tc_error_423  = [ NaN ; NaN ; NaN ];

%-- Image #424:
omc_424 = [ NaN ; NaN ; NaN ];
Tc_424  = [ NaN ; NaN ; NaN ];
omc_error_424 = [ NaN ; NaN ; NaN ];
Tc_error_424  = [ NaN ; NaN ; NaN ];

%-- Image #425:
omc_425 = [ NaN ; NaN ; NaN ];
Tc_425  = [ NaN ; NaN ; NaN ];
omc_error_425 = [ NaN ; NaN ; NaN ];
Tc_error_425  = [ NaN ; NaN ; NaN ];

%-- Image #426:
omc_426 = [ NaN ; NaN ; NaN ];
Tc_426  = [ NaN ; NaN ; NaN ];
omc_error_426 = [ NaN ; NaN ; NaN ];
Tc_error_426  = [ NaN ; NaN ; NaN ];

%-- Image #427:
omc_427 = [ NaN ; NaN ; NaN ];
Tc_427  = [ NaN ; NaN ; NaN ];
omc_error_427 = [ NaN ; NaN ; NaN ];
Tc_error_427  = [ NaN ; NaN ; NaN ];

%-- Image #428:
omc_428 = [ NaN ; NaN ; NaN ];
Tc_428  = [ NaN ; NaN ; NaN ];
omc_error_428 = [ NaN ; NaN ; NaN ];
Tc_error_428  = [ NaN ; NaN ; NaN ];

%-- Image #429:
omc_429 = [ NaN ; NaN ; NaN ];
Tc_429  = [ NaN ; NaN ; NaN ];
omc_error_429 = [ NaN ; NaN ; NaN ];
Tc_error_429  = [ NaN ; NaN ; NaN ];

%-- Image #430:
omc_430 = [ NaN ; NaN ; NaN ];
Tc_430  = [ NaN ; NaN ; NaN ];
omc_error_430 = [ NaN ; NaN ; NaN ];
Tc_error_430  = [ NaN ; NaN ; NaN ];

%-- Image #431:
omc_431 = [ NaN ; NaN ; NaN ];
Tc_431  = [ NaN ; NaN ; NaN ];
omc_error_431 = [ NaN ; NaN ; NaN ];
Tc_error_431  = [ NaN ; NaN ; NaN ];

%-- Image #432:
omc_432 = [ NaN ; NaN ; NaN ];
Tc_432  = [ NaN ; NaN ; NaN ];
omc_error_432 = [ NaN ; NaN ; NaN ];
Tc_error_432  = [ NaN ; NaN ; NaN ];

%-- Image #433:
omc_433 = [ NaN ; NaN ; NaN ];
Tc_433  = [ NaN ; NaN ; NaN ];
omc_error_433 = [ NaN ; NaN ; NaN ];
Tc_error_433  = [ NaN ; NaN ; NaN ];

%-- Image #434:
omc_434 = [ NaN ; NaN ; NaN ];
Tc_434  = [ NaN ; NaN ; NaN ];
omc_error_434 = [ NaN ; NaN ; NaN ];
Tc_error_434  = [ NaN ; NaN ; NaN ];

%-- Image #435:
omc_435 = [ NaN ; NaN ; NaN ];
Tc_435  = [ NaN ; NaN ; NaN ];
omc_error_435 = [ NaN ; NaN ; NaN ];
Tc_error_435  = [ NaN ; NaN ; NaN ];

%-- Image #436:
omc_436 = [ NaN ; NaN ; NaN ];
Tc_436  = [ NaN ; NaN ; NaN ];
omc_error_436 = [ NaN ; NaN ; NaN ];
Tc_error_436  = [ NaN ; NaN ; NaN ];

%-- Image #437:
omc_437 = [ NaN ; NaN ; NaN ];
Tc_437  = [ NaN ; NaN ; NaN ];
omc_error_437 = [ NaN ; NaN ; NaN ];
Tc_error_437  = [ NaN ; NaN ; NaN ];

%-- Image #438:
omc_438 = [ NaN ; NaN ; NaN ];
Tc_438  = [ NaN ; NaN ; NaN ];
omc_error_438 = [ NaN ; NaN ; NaN ];
Tc_error_438  = [ NaN ; NaN ; NaN ];

%-- Image #439:
omc_439 = [ NaN ; NaN ; NaN ];
Tc_439  = [ NaN ; NaN ; NaN ];
omc_error_439 = [ NaN ; NaN ; NaN ];
Tc_error_439  = [ NaN ; NaN ; NaN ];

%-- Image #440:
omc_440 = [ NaN ; NaN ; NaN ];
Tc_440  = [ NaN ; NaN ; NaN ];
omc_error_440 = [ NaN ; NaN ; NaN ];
Tc_error_440  = [ NaN ; NaN ; NaN ];

%-- Image #441:
omc_441 = [ NaN ; NaN ; NaN ];
Tc_441  = [ NaN ; NaN ; NaN ];
omc_error_441 = [ NaN ; NaN ; NaN ];
Tc_error_441  = [ NaN ; NaN ; NaN ];

%-- Image #442:
omc_442 = [ NaN ; NaN ; NaN ];
Tc_442  = [ NaN ; NaN ; NaN ];
omc_error_442 = [ NaN ; NaN ; NaN ];
Tc_error_442  = [ NaN ; NaN ; NaN ];

%-- Image #443:
omc_443 = [ NaN ; NaN ; NaN ];
Tc_443  = [ NaN ; NaN ; NaN ];
omc_error_443 = [ NaN ; NaN ; NaN ];
Tc_error_443  = [ NaN ; NaN ; NaN ];

%-- Image #444:
omc_444 = [ NaN ; NaN ; NaN ];
Tc_444  = [ NaN ; NaN ; NaN ];
omc_error_444 = [ NaN ; NaN ; NaN ];
Tc_error_444  = [ NaN ; NaN ; NaN ];

%-- Image #445:
omc_445 = [ NaN ; NaN ; NaN ];
Tc_445  = [ NaN ; NaN ; NaN ];
omc_error_445 = [ NaN ; NaN ; NaN ];
Tc_error_445  = [ NaN ; NaN ; NaN ];

%-- Image #446:
omc_446 = [ NaN ; NaN ; NaN ];
Tc_446  = [ NaN ; NaN ; NaN ];
omc_error_446 = [ NaN ; NaN ; NaN ];
Tc_error_446  = [ NaN ; NaN ; NaN ];

%-- Image #447:
omc_447 = [ NaN ; NaN ; NaN ];
Tc_447  = [ NaN ; NaN ; NaN ];
omc_error_447 = [ NaN ; NaN ; NaN ];
Tc_error_447  = [ NaN ; NaN ; NaN ];

%-- Image #448:
omc_448 = [ NaN ; NaN ; NaN ];
Tc_448  = [ NaN ; NaN ; NaN ];
omc_error_448 = [ NaN ; NaN ; NaN ];
Tc_error_448  = [ NaN ; NaN ; NaN ];

%-- Image #449:
omc_449 = [ NaN ; NaN ; NaN ];
Tc_449  = [ NaN ; NaN ; NaN ];
omc_error_449 = [ NaN ; NaN ; NaN ];
Tc_error_449  = [ NaN ; NaN ; NaN ];

%-- Image #450:
omc_450 = [ NaN ; NaN ; NaN ];
Tc_450  = [ NaN ; NaN ; NaN ];
omc_error_450 = [ NaN ; NaN ; NaN ];
Tc_error_450  = [ NaN ; NaN ; NaN ];

%-- Image #451:
omc_451 = [ NaN ; NaN ; NaN ];
Tc_451  = [ NaN ; NaN ; NaN ];
omc_error_451 = [ NaN ; NaN ; NaN ];
Tc_error_451  = [ NaN ; NaN ; NaN ];

%-- Image #452:
omc_452 = [ NaN ; NaN ; NaN ];
Tc_452  = [ NaN ; NaN ; NaN ];
omc_error_452 = [ NaN ; NaN ; NaN ];
Tc_error_452  = [ NaN ; NaN ; NaN ];

%-- Image #453:
omc_453 = [ NaN ; NaN ; NaN ];
Tc_453  = [ NaN ; NaN ; NaN ];
omc_error_453 = [ NaN ; NaN ; NaN ];
Tc_error_453  = [ NaN ; NaN ; NaN ];

%-- Image #454:
omc_454 = [ NaN ; NaN ; NaN ];
Tc_454  = [ NaN ; NaN ; NaN ];
omc_error_454 = [ NaN ; NaN ; NaN ];
Tc_error_454  = [ NaN ; NaN ; NaN ];

%-- Image #455:
omc_455 = [ NaN ; NaN ; NaN ];
Tc_455  = [ NaN ; NaN ; NaN ];
omc_error_455 = [ NaN ; NaN ; NaN ];
Tc_error_455  = [ NaN ; NaN ; NaN ];

%-- Image #456:
omc_456 = [ NaN ; NaN ; NaN ];
Tc_456  = [ NaN ; NaN ; NaN ];
omc_error_456 = [ NaN ; NaN ; NaN ];
Tc_error_456  = [ NaN ; NaN ; NaN ];

%-- Image #457:
omc_457 = [ NaN ; NaN ; NaN ];
Tc_457  = [ NaN ; NaN ; NaN ];
omc_error_457 = [ NaN ; NaN ; NaN ];
Tc_error_457  = [ NaN ; NaN ; NaN ];

%-- Image #458:
omc_458 = [ NaN ; NaN ; NaN ];
Tc_458  = [ NaN ; NaN ; NaN ];
omc_error_458 = [ NaN ; NaN ; NaN ];
Tc_error_458  = [ NaN ; NaN ; NaN ];

%-- Image #459:
omc_459 = [ NaN ; NaN ; NaN ];
Tc_459  = [ NaN ; NaN ; NaN ];
omc_error_459 = [ NaN ; NaN ; NaN ];
Tc_error_459  = [ NaN ; NaN ; NaN ];

%-- Image #460:
omc_460 = [ NaN ; NaN ; NaN ];
Tc_460  = [ NaN ; NaN ; NaN ];
omc_error_460 = [ NaN ; NaN ; NaN ];
Tc_error_460  = [ NaN ; NaN ; NaN ];

%-- Image #461:
omc_461 = [ NaN ; NaN ; NaN ];
Tc_461  = [ NaN ; NaN ; NaN ];
omc_error_461 = [ NaN ; NaN ; NaN ];
Tc_error_461  = [ NaN ; NaN ; NaN ];

%-- Image #462:
omc_462 = [ NaN ; NaN ; NaN ];
Tc_462  = [ NaN ; NaN ; NaN ];
omc_error_462 = [ NaN ; NaN ; NaN ];
Tc_error_462  = [ NaN ; NaN ; NaN ];

%-- Image #463:
omc_463 = [ NaN ; NaN ; NaN ];
Tc_463  = [ NaN ; NaN ; NaN ];
omc_error_463 = [ NaN ; NaN ; NaN ];
Tc_error_463  = [ NaN ; NaN ; NaN ];

%-- Image #464:
omc_464 = [ NaN ; NaN ; NaN ];
Tc_464  = [ NaN ; NaN ; NaN ];
omc_error_464 = [ NaN ; NaN ; NaN ];
Tc_error_464  = [ NaN ; NaN ; NaN ];

%-- Image #465:
omc_465 = [ NaN ; NaN ; NaN ];
Tc_465  = [ NaN ; NaN ; NaN ];
omc_error_465 = [ NaN ; NaN ; NaN ];
Tc_error_465  = [ NaN ; NaN ; NaN ];

%-- Image #466:
omc_466 = [ NaN ; NaN ; NaN ];
Tc_466  = [ NaN ; NaN ; NaN ];
omc_error_466 = [ NaN ; NaN ; NaN ];
Tc_error_466  = [ NaN ; NaN ; NaN ];

%-- Image #467:
omc_467 = [ NaN ; NaN ; NaN ];
Tc_467  = [ NaN ; NaN ; NaN ];
omc_error_467 = [ NaN ; NaN ; NaN ];
Tc_error_467  = [ NaN ; NaN ; NaN ];

%-- Image #468:
omc_468 = [ NaN ; NaN ; NaN ];
Tc_468  = [ NaN ; NaN ; NaN ];
omc_error_468 = [ NaN ; NaN ; NaN ];
Tc_error_468  = [ NaN ; NaN ; NaN ];

%-- Image #469:
omc_469 = [ NaN ; NaN ; NaN ];
Tc_469  = [ NaN ; NaN ; NaN ];
omc_error_469 = [ NaN ; NaN ; NaN ];
Tc_error_469  = [ NaN ; NaN ; NaN ];

%-- Image #470:
omc_470 = [ NaN ; NaN ; NaN ];
Tc_470  = [ NaN ; NaN ; NaN ];
omc_error_470 = [ NaN ; NaN ; NaN ];
Tc_error_470  = [ NaN ; NaN ; NaN ];

%-- Image #471:
omc_471 = [ NaN ; NaN ; NaN ];
Tc_471  = [ NaN ; NaN ; NaN ];
omc_error_471 = [ NaN ; NaN ; NaN ];
Tc_error_471  = [ NaN ; NaN ; NaN ];

%-- Image #472:
omc_472 = [ NaN ; NaN ; NaN ];
Tc_472  = [ NaN ; NaN ; NaN ];
omc_error_472 = [ NaN ; NaN ; NaN ];
Tc_error_472  = [ NaN ; NaN ; NaN ];

%-- Image #473:
omc_473 = [ NaN ; NaN ; NaN ];
Tc_473  = [ NaN ; NaN ; NaN ];
omc_error_473 = [ NaN ; NaN ; NaN ];
Tc_error_473  = [ NaN ; NaN ; NaN ];

%-- Image #474:
omc_474 = [ NaN ; NaN ; NaN ];
Tc_474  = [ NaN ; NaN ; NaN ];
omc_error_474 = [ NaN ; NaN ; NaN ];
Tc_error_474  = [ NaN ; NaN ; NaN ];

%-- Image #475:
omc_475 = [ 2.672922e+00 ; -7.486188e-01 ; 8.998047e-01 ];
Tc_475  = [ -5.352312e+02 ; 5.075209e+02 ; 8.405966e+02 ];
omc_error_475 = [ 3.502447e-03 ; 2.588007e-03 ; 4.653698e-03 ];
Tc_error_475  = [ 3.106222e+00 ; 4.278110e+00 ; 3.914592e+00 ];

%-- Image #476:
omc_476 = [ NaN ; NaN ; NaN ];
Tc_476  = [ NaN ; NaN ; NaN ];
omc_error_476 = [ NaN ; NaN ; NaN ];
Tc_error_476  = [ NaN ; NaN ; NaN ];

%-- Image #477:
omc_477 = [ 2.696295e+00 ; -3.780169e-01 ; 7.670049e-01 ];
Tc_477  = [ -4.766117e+02 ; 5.022029e+02 ; 8.611576e+02 ];
omc_error_477 = [ 3.675913e-03 ; 2.376305e-03 ; 4.161733e-03 ];
Tc_error_477  = [ 3.147346e+00 ; 4.355228e+00 ; 4.311746e+00 ];

%-- Image #478:
omc_478 = [ NaN ; NaN ; NaN ];
Tc_478  = [ NaN ; NaN ; NaN ];
omc_error_478 = [ NaN ; NaN ; NaN ];
Tc_error_478  = [ NaN ; NaN ; NaN ];

%-- Image #479:
omc_479 = [ NaN ; NaN ; NaN ];
Tc_479  = [ NaN ; NaN ; NaN ];
omc_error_479 = [ NaN ; NaN ; NaN ];
Tc_error_479  = [ NaN ; NaN ; NaN ];

%-- Image #480:
omc_480 = [ NaN ; NaN ; NaN ];
Tc_480  = [ NaN ; NaN ; NaN ];
omc_error_480 = [ NaN ; NaN ; NaN ];
Tc_error_480  = [ NaN ; NaN ; NaN ];

%-- Image #481:
omc_481 = [ NaN ; NaN ; NaN ];
Tc_481  = [ NaN ; NaN ; NaN ];
omc_error_481 = [ NaN ; NaN ; NaN ];
Tc_error_481  = [ NaN ; NaN ; NaN ];

%-- Image #482:
omc_482 = [ NaN ; NaN ; NaN ];
Tc_482  = [ NaN ; NaN ; NaN ];
omc_error_482 = [ NaN ; NaN ; NaN ];
Tc_error_482  = [ NaN ; NaN ; NaN ];

%-- Image #483:
omc_483 = [ 2.502362e+00 ; 1.704098e-01 ; 2.782981e-01 ];
Tc_483  = [ -1.046623e+02 ; 7.560119e+02 ; 8.602768e+02 ];
omc_error_483 = [ 3.687745e-03 ; 1.557749e-03 ; 3.274030e-03 ];
Tc_error_483  = [ 3.087721e+00 ; 4.857689e+00 ; 4.881545e+00 ];

%-- Image #484:
omc_484 = [ NaN ; NaN ; NaN ];
Tc_484  = [ NaN ; NaN ; NaN ];
omc_error_484 = [ NaN ; NaN ; NaN ];
Tc_error_484  = [ NaN ; NaN ; NaN ];

%-- Image #485:
omc_485 = [ NaN ; NaN ; NaN ];
Tc_485  = [ NaN ; NaN ; NaN ];
omc_error_485 = [ NaN ; NaN ; NaN ];
Tc_error_485  = [ NaN ; NaN ; NaN ];

%-- Image #486:
omc_486 = [ NaN ; NaN ; NaN ];
Tc_486  = [ NaN ; NaN ; NaN ];
omc_error_486 = [ NaN ; NaN ; NaN ];
Tc_error_486  = [ NaN ; NaN ; NaN ];

%-- Image #487:
omc_487 = [ NaN ; NaN ; NaN ];
Tc_487  = [ NaN ; NaN ; NaN ];
omc_error_487 = [ NaN ; NaN ; NaN ];
Tc_error_487  = [ NaN ; NaN ; NaN ];

%-- Image #488:
omc_488 = [ NaN ; NaN ; NaN ];
Tc_488  = [ NaN ; NaN ; NaN ];
omc_error_488 = [ NaN ; NaN ; NaN ];
Tc_error_488  = [ NaN ; NaN ; NaN ];

%-- Image #489:
omc_489 = [ NaN ; NaN ; NaN ];
Tc_489  = [ NaN ; NaN ; NaN ];
omc_error_489 = [ NaN ; NaN ; NaN ];
Tc_error_489  = [ NaN ; NaN ; NaN ];

%-- Image #490:
omc_490 = [ NaN ; NaN ; NaN ];
Tc_490  = [ NaN ; NaN ; NaN ];
omc_error_490 = [ NaN ; NaN ; NaN ];
Tc_error_490  = [ NaN ; NaN ; NaN ];

%-- Image #491:
omc_491 = [ NaN ; NaN ; NaN ];
Tc_491  = [ NaN ; NaN ; NaN ];
omc_error_491 = [ NaN ; NaN ; NaN ];
Tc_error_491  = [ NaN ; NaN ; NaN ];

%-- Image #492:
omc_492 = [ NaN ; NaN ; NaN ];
Tc_492  = [ NaN ; NaN ; NaN ];
omc_error_492 = [ NaN ; NaN ; NaN ];
Tc_error_492  = [ NaN ; NaN ; NaN ];

%-- Image #493:
omc_493 = [ NaN ; NaN ; NaN ];
Tc_493  = [ NaN ; NaN ; NaN ];
omc_error_493 = [ NaN ; NaN ; NaN ];
Tc_error_493  = [ NaN ; NaN ; NaN ];

%-- Image #494:
omc_494 = [ NaN ; NaN ; NaN ];
Tc_494  = [ NaN ; NaN ; NaN ];
omc_error_494 = [ NaN ; NaN ; NaN ];
Tc_error_494  = [ NaN ; NaN ; NaN ];

%-- Image #495:
omc_495 = [ NaN ; NaN ; NaN ];
Tc_495  = [ NaN ; NaN ; NaN ];
omc_error_495 = [ NaN ; NaN ; NaN ];
Tc_error_495  = [ NaN ; NaN ; NaN ];

%-- Image #496:
omc_496 = [ NaN ; NaN ; NaN ];
Tc_496  = [ NaN ; NaN ; NaN ];
omc_error_496 = [ NaN ; NaN ; NaN ];
Tc_error_496  = [ NaN ; NaN ; NaN ];

%-- Image #497:
omc_497 = [ NaN ; NaN ; NaN ];
Tc_497  = [ NaN ; NaN ; NaN ];
omc_error_497 = [ NaN ; NaN ; NaN ];
Tc_error_497  = [ NaN ; NaN ; NaN ];

%-- Image #498:
omc_498 = [ NaN ; NaN ; NaN ];
Tc_498  = [ NaN ; NaN ; NaN ];
omc_error_498 = [ NaN ; NaN ; NaN ];
Tc_error_498  = [ NaN ; NaN ; NaN ];

%-- Image #499:
omc_499 = [ NaN ; NaN ; NaN ];
Tc_499  = [ NaN ; NaN ; NaN ];
omc_error_499 = [ NaN ; NaN ; NaN ];
Tc_error_499  = [ NaN ; NaN ; NaN ];

%-- Image #500:
omc_500 = [ NaN ; NaN ; NaN ];
Tc_500  = [ NaN ; NaN ; NaN ];
omc_error_500 = [ NaN ; NaN ; NaN ];
Tc_error_500  = [ NaN ; NaN ; NaN ];

%-- Image #501:
omc_501 = [ NaN ; NaN ; NaN ];
Tc_501  = [ NaN ; NaN ; NaN ];
omc_error_501 = [ NaN ; NaN ; NaN ];
Tc_error_501  = [ NaN ; NaN ; NaN ];

%-- Image #502:
omc_502 = [ NaN ; NaN ; NaN ];
Tc_502  = [ NaN ; NaN ; NaN ];
omc_error_502 = [ NaN ; NaN ; NaN ];
Tc_error_502  = [ NaN ; NaN ; NaN ];

%-- Image #503:
omc_503 = [ NaN ; NaN ; NaN ];
Tc_503  = [ NaN ; NaN ; NaN ];
omc_error_503 = [ NaN ; NaN ; NaN ];
Tc_error_503  = [ NaN ; NaN ; NaN ];

%-- Image #504:
omc_504 = [ NaN ; NaN ; NaN ];
Tc_504  = [ NaN ; NaN ; NaN ];
omc_error_504 = [ NaN ; NaN ; NaN ];
Tc_error_504  = [ NaN ; NaN ; NaN ];

%-- Image #505:
omc_505 = [ NaN ; NaN ; NaN ];
Tc_505  = [ NaN ; NaN ; NaN ];
omc_error_505 = [ NaN ; NaN ; NaN ];
Tc_error_505  = [ NaN ; NaN ; NaN ];

%-- Image #506:
omc_506 = [ NaN ; NaN ; NaN ];
Tc_506  = [ NaN ; NaN ; NaN ];
omc_error_506 = [ NaN ; NaN ; NaN ];
Tc_error_506  = [ NaN ; NaN ; NaN ];

%-- Image #507:
omc_507 = [ NaN ; NaN ; NaN ];
Tc_507  = [ NaN ; NaN ; NaN ];
omc_error_507 = [ NaN ; NaN ; NaN ];
Tc_error_507  = [ NaN ; NaN ; NaN ];

%-- Image #508:
omc_508 = [ NaN ; NaN ; NaN ];
Tc_508  = [ NaN ; NaN ; NaN ];
omc_error_508 = [ NaN ; NaN ; NaN ];
Tc_error_508  = [ NaN ; NaN ; NaN ];

%-- Image #509:
omc_509 = [ NaN ; NaN ; NaN ];
Tc_509  = [ NaN ; NaN ; NaN ];
omc_error_509 = [ NaN ; NaN ; NaN ];
Tc_error_509  = [ NaN ; NaN ; NaN ];

%-- Image #510:
omc_510 = [ NaN ; NaN ; NaN ];
Tc_510  = [ NaN ; NaN ; NaN ];
omc_error_510 = [ NaN ; NaN ; NaN ];
Tc_error_510  = [ NaN ; NaN ; NaN ];

%-- Image #511:
omc_511 = [ NaN ; NaN ; NaN ];
Tc_511  = [ NaN ; NaN ; NaN ];
omc_error_511 = [ NaN ; NaN ; NaN ];
Tc_error_511  = [ NaN ; NaN ; NaN ];

%-- Image #512:
omc_512 = [ NaN ; NaN ; NaN ];
Tc_512  = [ NaN ; NaN ; NaN ];
omc_error_512 = [ NaN ; NaN ; NaN ];
Tc_error_512  = [ NaN ; NaN ; NaN ];

%-- Image #513:
omc_513 = [ NaN ; NaN ; NaN ];
Tc_513  = [ NaN ; NaN ; NaN ];
omc_error_513 = [ NaN ; NaN ; NaN ];
Tc_error_513  = [ NaN ; NaN ; NaN ];

%-- Image #514:
omc_514 = [ NaN ; NaN ; NaN ];
Tc_514  = [ NaN ; NaN ; NaN ];
omc_error_514 = [ NaN ; NaN ; NaN ];
Tc_error_514  = [ NaN ; NaN ; NaN ];

%-- Image #515:
omc_515 = [ NaN ; NaN ; NaN ];
Tc_515  = [ NaN ; NaN ; NaN ];
omc_error_515 = [ NaN ; NaN ; NaN ];
Tc_error_515  = [ NaN ; NaN ; NaN ];

%-- Image #516:
omc_516 = [ NaN ; NaN ; NaN ];
Tc_516  = [ NaN ; NaN ; NaN ];
omc_error_516 = [ NaN ; NaN ; NaN ];
Tc_error_516  = [ NaN ; NaN ; NaN ];

%-- Image #517:
omc_517 = [ NaN ; NaN ; NaN ];
Tc_517  = [ NaN ; NaN ; NaN ];
omc_error_517 = [ NaN ; NaN ; NaN ];
Tc_error_517  = [ NaN ; NaN ; NaN ];

%-- Image #518:
omc_518 = [ 2.376615e+00 ; -6.474872e-01 ; 1.261505e-01 ];
Tc_518  = [ 1.693705e+01 ; 6.785282e+02 ; 7.478594e+02 ];
omc_error_518 = [ 3.919915e-03 ; 1.617596e-03 ; 3.041755e-03 ];
Tc_error_518  = [ 2.739937e+00 ; 4.114288e+00 ; 3.791482e+00 ];

%-- Image #519:
omc_519 = [ NaN ; NaN ; NaN ];
Tc_519  = [ NaN ; NaN ; NaN ];
omc_error_519 = [ NaN ; NaN ; NaN ];
Tc_error_519  = [ NaN ; NaN ; NaN ];

%-- Image #520:
omc_520 = [ NaN ; NaN ; NaN ];
Tc_520  = [ NaN ; NaN ; NaN ];
omc_error_520 = [ NaN ; NaN ; NaN ];
Tc_error_520  = [ NaN ; NaN ; NaN ];

%-- Image #521:
omc_521 = [ 2.384048e+00 ; -5.483223e-01 ; 1.543784e-01 ];
Tc_521  = [ -1.242282e+02 ; 6.732241e+02 ; 7.425837e+02 ];
omc_error_521 = [ 3.916854e-03 ; 1.509985e-03 ; 3.100973e-03 ];
Tc_error_521  = [ 2.690086e+00 ; 4.130338e+00 ; 3.896597e+00 ];

%-- Image #522:
omc_522 = [ NaN ; NaN ; NaN ];
Tc_522  = [ NaN ; NaN ; NaN ];
omc_error_522 = [ NaN ; NaN ; NaN ];
Tc_error_522  = [ NaN ; NaN ; NaN ];

%-- Image #523:
omc_523 = [ NaN ; NaN ; NaN ];
Tc_523  = [ NaN ; NaN ; NaN ];
omc_error_523 = [ NaN ; NaN ; NaN ];
Tc_error_523  = [ NaN ; NaN ; NaN ];

%-- Image #524:
omc_524 = [ NaN ; NaN ; NaN ];
Tc_524  = [ NaN ; NaN ; NaN ];
omc_error_524 = [ NaN ; NaN ; NaN ];
Tc_error_524  = [ NaN ; NaN ; NaN ];

%-- Image #525:
omc_525 = [ NaN ; NaN ; NaN ];
Tc_525  = [ NaN ; NaN ; NaN ];
omc_error_525 = [ NaN ; NaN ; NaN ];
Tc_error_525  = [ NaN ; NaN ; NaN ];

%-- Image #526:
omc_526 = [ 2.442509e+00 ; -5.084348e-01 ; 1.941943e-01 ];
Tc_526  = [ -2.296515e+02 ; 6.167885e+02 ; 7.015559e+02 ];
omc_error_526 = [ 3.679939e-03 ; 1.433152e-03 ; 2.956976e-03 ];
Tc_error_526  = [ 2.517609e+00 ; 3.902673e+00 ; 3.761757e+00 ];

%-- Image #527:
omc_527 = [ NaN ; NaN ; NaN ];
Tc_527  = [ NaN ; NaN ; NaN ];
omc_error_527 = [ NaN ; NaN ; NaN ];
Tc_error_527  = [ NaN ; NaN ; NaN ];

%-- Image #528:
omc_528 = [ NaN ; NaN ; NaN ];
Tc_528  = [ NaN ; NaN ; NaN ];
omc_error_528 = [ NaN ; NaN ; NaN ];
Tc_error_528  = [ NaN ; NaN ; NaN ];

%-- Image #529:
omc_529 = [ NaN ; NaN ; NaN ];
Tc_529  = [ NaN ; NaN ; NaN ];
omc_error_529 = [ NaN ; NaN ; NaN ];
Tc_error_529  = [ NaN ; NaN ; NaN ];

%-- Image #530:
omc_530 = [ NaN ; NaN ; NaN ];
Tc_530  = [ NaN ; NaN ; NaN ];
omc_error_530 = [ NaN ; NaN ; NaN ];
Tc_error_530  = [ NaN ; NaN ; NaN ];

%-- Image #531:
omc_531 = [ NaN ; NaN ; NaN ];
Tc_531  = [ NaN ; NaN ; NaN ];
omc_error_531 = [ NaN ; NaN ; NaN ];
Tc_error_531  = [ NaN ; NaN ; NaN ];

%-- Image #532:
omc_532 = [ NaN ; NaN ; NaN ];
Tc_532  = [ NaN ; NaN ; NaN ];
omc_error_532 = [ NaN ; NaN ; NaN ];
Tc_error_532  = [ NaN ; NaN ; NaN ];

%-- Image #533:
omc_533 = [ NaN ; NaN ; NaN ];
Tc_533  = [ NaN ; NaN ; NaN ];
omc_error_533 = [ NaN ; NaN ; NaN ];
Tc_error_533  = [ NaN ; NaN ; NaN ];

%-- Image #534:
omc_534 = [ NaN ; NaN ; NaN ];
Tc_534  = [ NaN ; NaN ; NaN ];
omc_error_534 = [ NaN ; NaN ; NaN ];
Tc_error_534  = [ NaN ; NaN ; NaN ];

%-- Image #535:
omc_535 = [ 2.512181e+00 ; -7.072162e-01 ; 3.341818e-01 ];
Tc_535  = [ -3.353280e+02 ; 5.268032e+02 ; 5.439663e+02 ];
omc_error_535 = [ 3.088809e-03 ; 1.514256e-03 ; 2.590057e-03 ];
Tc_error_535  = [ 2.056855e+00 ; 3.090021e+00 ; 3.039317e+00 ];

%-- Image #536:
omc_536 = [ NaN ; NaN ; NaN ];
Tc_536  = [ NaN ; NaN ; NaN ];
omc_error_536 = [ NaN ; NaN ; NaN ];
Tc_error_536  = [ NaN ; NaN ; NaN ];

%-- Image #537:
omc_537 = [ NaN ; NaN ; NaN ];
Tc_537  = [ NaN ; NaN ; NaN ];
omc_error_537 = [ NaN ; NaN ; NaN ];
Tc_error_537  = [ NaN ; NaN ; NaN ];

%-- Image #538:
omc_538 = [ NaN ; NaN ; NaN ];
Tc_538  = [ NaN ; NaN ; NaN ];
omc_error_538 = [ NaN ; NaN ; NaN ];
Tc_error_538  = [ NaN ; NaN ; NaN ];

%-- Image #539:
omc_539 = [ 2.466023e+00 ; -5.353448e-01 ; 2.239376e-01 ];
Tc_539  = [ -3.105325e+02 ; 5.219647e+02 ; 4.954116e+02 ];
omc_error_539 = [ 3.372560e-03 ; 1.300145e-03 ; 2.388222e-03 ];
Tc_error_539  = [ 1.916128e+00 ; 2.860255e+00 ; 2.744273e+00 ];

